@@ -7,16 +7,20 @@ import copy
 
 from azure.cli.core import azclierror
 from knack.arguments import CLICommandArgument, CaseInsensitiveList
+from knack.preview import PreviewItem
+from knack.experimental import ExperimentalItem
+from knack.util import status_tag_messages
 
 from ._arg_action import AAZSimpleTypeArgAction, AAZObjectArgAction, AAZDictArgAction, AAZFreeFormDictArgAction, \
     AAZListArgAction, AAZGenericUpdateAction, AAZGenericUpdateForceStringAction
-from ._base import AAZBaseType, AAZUndefined
+from ._base import AAZBaseType, AAZUndefined, AAZBaseValue
 from ._field_type import AAZObjectType, AAZStrType, AAZIntType, AAZBoolType, AAZFloatType, AAZListType, AAZDictType, \
     AAZSimpleType, AAZFreeFormDictType
 from ._field_value import AAZObject
 from ._arg_fmt import AAZObjectArgFormat, AAZListArgFormat, AAZDictArgFormat, AAZFreeFormDictArgFormat, \
     AAZSubscriptionIdArgFormat, AAZResourceLocationArgFormat, AAZResourceIdArgFormat, AAZUuidFormat, AAZDateFormat, \
     AAZTimeFormat, AAZDateTimeFormat, AAZDurationFormat
+from .exceptions import AAZUnregisteredArg
 
 # pylint: disable=redefined-builtin, protected-access, too-few-public-methods
 
@@ -72,7 +76,7 @@ class AAZBaseArg(AAZBaseType):  # pylint: disable=too-many-instance-attributes
     """Base argument"""
 
     def __init__(self, options=None, required=False, help=None, arg_group=None, is_preview=False, is_experimental=False,
-                 id_part=None, default=AAZUndefined, blank=AAZUndefined, nullable=False, fmt=None):
+                 id_part=None, default=AAZUndefined, blank=AAZUndefined, nullable=False, fmt=None, registered=True):
         """
 
         :param options: argument optional names.
@@ -87,6 +91,7 @@ class AAZBaseArg(AAZBaseType):  # pylint: disable=too-many-instance-attributes
         :param blank: when the argument flag is used without value data, the blank value will be used.
         :param nullable: argument can accept `None` as value
         :param fmt: argument format
+        :param registered: control whether register argument into command display
         """
         super().__init__(options=options, nullable=nullable)
         self._help = {}  # the key in self._help can be 'name', 'short-summary', 'long-summary', 'populator-commands'
@@ -106,12 +111,18 @@ class AAZBaseArg(AAZBaseType):  # pylint: disable=too-many-instance-attributes
         self._default = default
         self._blank = blank
         self._fmt = fmt
+        self._registered = registered
 
-    def to_cmd_arg(self, name):
+    def to_cmd_arg(self, name, **kwargs):
         """ convert AAZArg to CLICommandArgument """
+        if not self._registered:
+            # argument will not registered in command display
+            raise AAZUnregisteredArg()
+
+        options_list = [*self._options] if self._options else None
         arg = CLICommandArgument(
             dest=name,
-            options_list=[*self._options] if self._options else None,
+            options_list=options_list,
             # if default is not None, arg is not required.
             required=self._required if self._default == AAZUndefined else False,
             help=self._help.get('short-summary', None),
@@ -124,6 +135,42 @@ class AAZBaseArg(AAZBaseType):  # pylint: disable=too-many-instance-attributes
         if self._blank != AAZUndefined:
             arg.nargs = '?'
 
+        cli_ctx = kwargs.get('cli_ctx', None)
+        if cli_ctx is None:
+            # define mock cli_ctx for PreviewItem and ExperimentalItem
+            class _CLI_CTX:
+                enable_color = False
+            cli_ctx = _CLI_CTX
+
+        if options_list is None:
+            target = f"--{name.replace('_', '-')}"
+        else:
+            target = sorted(options_list, key=len)[-1]
+
+        if self._is_preview:
+            def _get_preview_arg_message(self):
+                subject = "{} '{}'".format(self.object_type.capitalize(), self.target)
+                return status_tag_messages['preview'].format(subject)
+            arg.preview_info = PreviewItem(
+                cli_ctx=cli_ctx,
+                target=target,
+                object_type="argument",
+                message_func=_get_preview_arg_message
+            )
+
+        if self._is_experimental:
+            def _get_experimental_arg_message(self):
+                # "Argument xxx"
+                subject = "{} '{}'".format(self.object_type.capitalize(), self.target)
+                return status_tag_messages['experimental'].format(subject)
+
+            arg.experimental_info = ExperimentalItem(
+                cli_ctx=cli_ctx,
+                target=target,
+                object_type="argument",
+                message_func=_get_experimental_arg_message
+            )
+
         action = self._build_cmd_action()   # call sub class's implementation to build CLICommandArgument action
         if action:
             arg.action = action
@@ -148,8 +195,8 @@ class AAZSimpleTypeArg(AAZBaseArg, AAZSimpleType):
         super().__init__(**kwargs)
         self.enum = AAZArgEnum(enum, case_sensitive=enum_case_sensitive) if enum else None
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         if self.enum:
             arg.choices = self.enum.to_choices()    # convert it's enum value into choices in arg
         return arg
@@ -260,9 +307,9 @@ class AAZCompoundTypeArg(AAZBaseArg):
     def _build_cmd_action(self):
         raise NotImplementedError()
 
-    def to_cmd_arg(self, name):
+    def to_cmd_arg(self, name, **kwargs):
         from ._help import shorthand_help_messages
-        arg = super().to_cmd_arg(name)
+        arg = super().to_cmd_arg(name, **kwargs)
         short_summary = arg.type.settings.get('help', None) or ''
         if short_summary:
             short_summary += '  '
@@ -281,8 +328,8 @@ class AAZObjectArg(AAZCompoundTypeArg, AAZObjectType):
         fmt = fmt or AAZObjectArgFormat()
         super().__init__(fmt=fmt, **kwargs)
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         if self._blank != AAZUndefined:
             arg.nargs = '*'
         else:
@@ -306,8 +353,8 @@ class AAZDictArg(AAZCompoundTypeArg, AAZDictType):
         fmt = fmt or AAZDictArgFormat()
         super().__init__(fmt=fmt, **kwargs)
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         if self._blank != AAZUndefined:
             arg.nargs = '*'
         else:
@@ -331,9 +378,8 @@ class AAZFreeFormDictArg(AAZBaseArg, AAZFreeFormDictType):
         fmt = fmt or AAZFreeFormDictArgFormat()
         super().__init__(fmt=fmt, **kwargs)
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
-
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         short_summary = arg.type.settings.get('help', None) or ''
         if short_summary:
             short_summary += '  '
@@ -359,8 +405,8 @@ class AAZListArg(AAZCompoundTypeArg, AAZListType):
         super().__init__(fmt=fmt, **kwargs)
         self.singular_options = singular_options
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         if self.singular_options:
             assert arg.options_list
             arg.options_list.extend(self.singular_options)  # support to parse singular options
@@ -396,11 +442,10 @@ class AAZResourceGroupNameArg(AAZStrArg):
             **kwargs
         )
 
-    def to_cmd_arg(self, name):
+    def to_cmd_arg(self, name, **kwargs):
         from azure.cli.core.commands.parameters import get_resource_group_completion_list
         from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction, ALL
-        arg = super().to_cmd_arg(name)
-
+        arg = super().to_cmd_arg(name, **kwargs)
         arg.completer = get_resource_group_completion_list
         arg.configured_default = 'group'
         arg.local_context_attribute = LocalContextAttribute(
@@ -427,10 +472,10 @@ class AAZResourceLocationArg(AAZStrArg):
             **kwargs
         )
 
-    def to_cmd_arg(self, name):
+    def to_cmd_arg(self, name, **kwargs):
         from azure.cli.core.commands.parameters import get_location_completion_list
         from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction, ALL
-        arg = super().to_cmd_arg(name)
+        arg = super().to_cmd_arg(name, **kwargs)
         if self._required and \
                 isinstance(self._fmt, AAZResourceLocationArgFormat) and self._fmt._resource_group_arg is not None:
             # when location is required and it will be retrived from resource group by default, arg is not required.
@@ -468,9 +513,9 @@ class AAZSubscriptionIdArg(AAZStrArg):
             **kwargs
         )
 
-    def to_cmd_arg(self, name):
+    def to_cmd_arg(self, name, **kwargs):
         from azure.cli.core._completers import get_subscription_id_list
-        arg = super().to_cmd_arg(name)
+        arg = super().to_cmd_arg(name, **kwargs)
         arg.completer = get_subscription_id_list
         return arg
 
@@ -521,8 +566,8 @@ class AAZGenericUpdateSetArg(AAZGenericUpdateArg):
             **kwargs,
         )
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         arg.nargs = '+'
         arg.metavar = 'KEY=VALUE'
         return arg
@@ -548,8 +593,8 @@ class AAZGenericUpdateAddArg(AAZGenericUpdateArg):
             **kwargs,
         )
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         arg.nargs = '+'
         arg.metavar = 'LIST KEY=VALUE'
         return arg
@@ -575,8 +620,8 @@ class AAZGenericUpdateRemoveArg(AAZGenericUpdateArg):
             **kwargs,
         )
 
-    def to_cmd_arg(self, name):
-        arg = super().to_cmd_arg(name)
+    def to_cmd_arg(self, name, **kwargs):
+        arg = super().to_cmd_arg(name, **kwargs)
         arg.nargs = '+'
         arg.metavar = 'LIST INDEX'
         return arg
@@ -588,4 +633,7 @@ class AAZGenericUpdateRemoveArg(AAZGenericUpdateArg):
 
 
 def has_value(arg_value):
+    if isinstance(arg_value, AAZBaseValue):
+        # handle patch value for list, object, dict
+        return arg_value.to_serialized_data() != AAZUndefined
     return arg_value != AAZUndefined
