@@ -469,6 +469,7 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_str_arg(self):
         from azure.cli.core.aaz._arg import AAZStrArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -493,6 +494,8 @@ class TestAAZArg(unittest.TestCase):
             nullable=True,
             blank="Sunday"
         )
+        self.assertFalse(has_value(v.work_day))
+
         arg = schema.work_day.to_cmd_arg("work_day")
         self.assertEqual(len(arg.choices), 14)
         action = arg.type.settings["action"]
@@ -581,6 +584,7 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_int_arg(self):
         from azure.cli.core.aaz._arg import AAZIntArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -595,6 +599,9 @@ class TestAAZArg(unittest.TestCase):
             nullable=True,
             blank=0
         )
+
+        self.assertFalse(has_value(v.score))
+
         arg = schema.score.to_cmd_arg("score")
         self.assertEqual(len(arg.choices), 4)
         action = arg.type.settings["action"]
@@ -670,6 +677,7 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_float_arg(self):
         from azure.cli.core.aaz._arg import AAZFloatArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -684,6 +692,8 @@ class TestAAZArg(unittest.TestCase):
             nullable=True,
             blank=0.0
         )
+        self.assertFalse(has_value(v.score))
+
         arg = schema.score.to_cmd_arg("score")
         self.assertEqual(len(arg.choices), 4)
         action = arg.type.settings["action"]
@@ -756,10 +766,13 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_bool_arg(self):
         from azure.cli.core.aaz._arg import AAZBoolArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
         schema.enable = AAZBoolArg(options=["--enable", "-e"])
+        self.assertFalse(has_value(v.enable))
+
         arg = schema.enable.to_cmd_arg("enable")
         self.assertEqual(len(arg.choices), 10)
         action = arg.type.settings["action"]
@@ -871,6 +884,7 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_list_arg(self):
         from azure.cli.core.aaz._arg import AAZListArg, AAZStrArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations, _ELEMENT_APPEND_KEY
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -883,6 +897,8 @@ class TestAAZArg(unittest.TestCase):
             blank="a blank value"
         )
 
+        self.assertFalse(has_value(v.names))
+
         arg = schema.names.to_cmd_arg("names")
         action = arg.type.settings["action"]
 
@@ -965,6 +981,7 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_dict_arg(self):
         from azure.cli.core.aaz._arg import AAZDictArg, AAZStrArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -976,6 +993,8 @@ class TestAAZArg(unittest.TestCase):
             blank="a blank value"
         )
 
+        self.assertFalse(has_value(v.tags))
+
         arg = schema.tags.to_cmd_arg("tags")
         action = arg.type.settings["action"]
 
@@ -1018,6 +1037,7 @@ class TestAAZArg(unittest.TestCase):
     def test_aaz_freeform_dict_arg(self):
         from azure.cli.core.aaz._arg import AAZFreeFormDictArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -1027,6 +1047,8 @@ class TestAAZArg(unittest.TestCase):
             blank={"blank": True}
         )
 
+        self.assertFalse(has_value(v.tags))
+
         arg = schema.tags.to_cmd_arg("tags")
         action = arg.type.settings["action"]
 
@@ -1069,11 +1091,11 @@ class TestAAZArg(unittest.TestCase):
         with self.assertRaises(aazerror.AAZInvalidValueError):
             action.setup_operations(dest_ops, "[1, 2, 3]")
 
-
     def test_aaz_object_arg(self):
         from azure.cli.core.aaz._arg import AAZDictArg, AAZListArg, AAZObjectArg, AAZIntArg, AAZBoolArg, AAZFloatArg, \
             AAZStrArg, AAZArgumentsSchema
         from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
         schema = AAZArgumentsSchema()
         v = schema()
 
@@ -1110,12 +1132,21 @@ class TestAAZArg(unittest.TestCase):
             blank="666"
         )
 
+        schema.properties.new_i_pv6 = AAZStrArg(
+            options=["new_ipv6"],
+        )
+
         schema.properties.pt = AAZFloatArg(
             options=["pt"],
             nullable=True,
             blank="0.1"
         )
 
+        self.assertFalse(has_value(v.properties.identities))
+        self.assertFalse(has_value(v.properties.vnets))
+        self.assertFalse(has_value(v.properties.pt))
+        self.assertFalse(has_value(v.properties))
+
         arg = schema.properties.to_cmd_arg("properties")
         action = arg.type.settings["action"]
 
@@ -1201,12 +1232,255 @@ class TestAAZArg(unittest.TestCase):
         dest_ops.apply(v, "properties")
         self.assertEqual(v.properties, None)
 
-        action.setup_operations(dest_ops, ["{enable:True,tags:null,vnets:null,pt:12.123}"])
+        action.setup_operations(dest_ops, ["{enable:True,tags:null,vnets:null,pt:12.123,newIPv6:'00:00:00'}"])
         self.assertEqual(len(dest_ops._ops), 10)
         dest_ops.apply(v, "properties")
         self.assertEqual(v.properties, {
             "enable": True,
             "tags": None,
             "vnets": None,
-            "pt": 12.123
+            "pt": 12.123,
+            "new_i_pv6": '00:00:00'
         })
+
+    def test_aaz_has_value_for_buildin(self):
+        from azure.cli.core.aaz import has_value, AAZUndefined
+        self.assertTrue(has_value(0))
+        self.assertTrue(has_value(""))
+        self.assertTrue(has_value(False))
+        self.assertTrue(has_value(None))
+
+        self.assertFalse(has_value(AAZUndefined))
+
+    def test_aaz_registered_arg(self):
+        from azure.cli.core.aaz._arg import AAZStrArg, AAZObjectArg, AAZBoolArg, AAZArgumentsSchema
+        from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value
+        from azure.cli.core.aaz.exceptions import AAZUnregisteredArg
+        schema = AAZArgumentsSchema()
+        v = schema()
+
+        schema.work_day = AAZStrArg(
+            options=["--work-day", "-d"],
+            enum={
+                "1": "Monday",
+                "2": "Tuesday",
+                "3": "Wednesday",
+                "4": "Thursday",
+                "5": "Friday",
+                "6": "Saturday",
+                "7": "Sunday",
+                "Mon": "Monday",
+                "Tue": "Tuesday",
+                "Wed": "Wednesday",
+                "Thu": "Thursday",
+                "Fri": "Friday",
+                "Sat": "Saturday",
+                "Sun": "Sunday",
+            },
+            nullable=True,
+            blank="Sunday"
+        )
+        self.assertTrue(schema.work_day._registered)
+
+        arg = schema.work_day.to_cmd_arg("work_day")
+
+        schema.work_day._registered = False
+        with self.assertRaises(AAZUnregisteredArg):
+            schema.work_day.to_cmd_arg("work_day")
+
+        schema.properties = AAZObjectArg(
+            options=["--prop", "-p"],
+            nullable=True
+        )
+
+        schema.properties.enable = AAZBoolArg(
+            options=["enable"],
+            nullable=True,
+        )
+
+        self.assertTrue(schema.properties._registered)
+        arg = schema.properties.to_cmd_arg("properties")
+
+        schema.properties._registered = False
+        with self.assertRaises(AAZUnregisteredArg):
+            schema.properties.to_cmd_arg("properties")
+
+
+class TestAAZArgUtils(unittest.TestCase):
+
+    def test_assign_aaz_list_arg(self):
+        from azure.cli.core.aaz.utils import assign_aaz_list_arg
+        from azure.cli.core.aaz._arg import AAZListArg, AAZStrArg, AAZObjectArg, AAZArgumentsSchema
+        from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value, AAZUndefined
+        schema = AAZArgumentsSchema()
+        v = schema()
+
+        schema.names = AAZListArg(
+            options=["--names", "--ns"],
+            singular_options=["--name", "-n"],
+            nullable=True
+        )
+        schema.names.Element = AAZStrArg(
+            nullable=True,
+            blank="a blank value"
+        )
+        schema.items = AAZListArg(
+            nullable=True,
+        )
+        schema.items.Element = AAZObjectArg(
+            nullable=True,
+        )
+        schema.items.Element.name = AAZStrArg()
+
+        # AAZUndefined
+        self.assertFalse(has_value(v.names))
+        v.items = assign_aaz_list_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertFalse(has_value(v.items))
+
+        v.items = [{"name": "1"}]
+        v.items = assign_aaz_list_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, [{"name": "1"}])
+
+        arg = schema.names.to_cmd_arg("names")
+        action = arg.type.settings["action"]
+
+        # null value
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["null"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, None)
+
+        v.items = assign_aaz_list_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, None)
+
+        # null element value
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["[0]=null"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, [None, ])
+
+        v.items = assign_aaz_list_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, [None, ])
+
+        # element
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["1", "2", "3"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, ['1', '2', '3'])
+        self.assertFalse(v.names._is_patch)
+
+        v.items = assign_aaz_list_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, [{"name": '1'}, {"name": '2'}, {"name": "3"}])
+        self.assertFalse(v.items._is_patch)
+
+        # patch element
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["[3]=n5"])
+        dest_ops.apply(v, "names")
+        self.assertTrue(v.names._is_patch)
+        self.assertEqual(len(v.names), 4)
+        self.assertFalse(has_value(v.items[0]))
+        self.assertFalse(has_value(v.items[1]))
+        self.assertFalse(has_value(v.items[2]))
+        self.assertEqual(v.names[3], 'n5')
+        v.items = assign_aaz_list_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertTrue(v.items._is_patch)
+        self.assertEqual(len(v.items), 4)
+        self.assertFalse(has_value(v.items[0]))
+        self.assertFalse(has_value(v.items[1]))
+        self.assertFalse(has_value(v.items[2]))
+        self.assertEqual(v.items[3], {"name": 'n5'})
+
+    def test_assign_aaz_dict_arg(self):
+        from azure.cli.core.aaz.utils import assign_aaz_dict_arg
+        from azure.cli.core.aaz._arg import AAZDictArg, AAZStrArg, AAZObjectArg, AAZArgumentsSchema
+        from azure.cli.core.aaz._arg_action import AAZArgActionOperations
+        from azure.cli.core.aaz import has_value, AAZUndefined
+        schema = AAZArgumentsSchema()
+        v = schema()
+
+        schema.names = AAZDictArg(
+            options=["--names", "--ns"],
+            nullable=True
+        )
+        schema.names.Element = AAZStrArg(
+            nullable=True,
+            blank="a blank value"
+        )
+        schema.items = AAZDictArg(
+            nullable=True,
+        )
+        schema.items.Element = AAZObjectArg(
+            nullable=True,
+        )
+        schema.items.Element.name = AAZStrArg()
+
+        # AAZUndefined
+        self.assertFalse(has_value(v.names))
+        v.items = assign_aaz_dict_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertFalse(has_value(v.items))
+
+        v.items = {"a": {"name": "1"}}
+        v.items = assign_aaz_dict_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, {"a": {"name": "1"}})
+
+        arg = schema.names.to_cmd_arg("names")
+        action = arg.type.settings["action"]
+
+        # null value
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["null"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, None)
+
+        v.items = assign_aaz_dict_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, None)
+
+        # null element value
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["a=null"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, {'a': None})
+
+        v.items = assign_aaz_dict_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertEqual(v.items, {'a': None})
+
+        # element
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["{a:a1,b:b2}"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, {'a': 'a1', 'b': 'b2'})
+        self.assertFalse(v.names._is_patch)
+
+        v.items = assign_aaz_dict_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertFalse(v.items._is_patch)
+        self.assertEqual(v.items, {'a': {"name": 'a1'}, 'b': {"name": 'b2'}})
+
+        # element with patch
+        v = schema()
+        dest_ops = AAZArgActionOperations()
+
+        action.setup_operations(dest_ops, ["a=1", "b=2", "c=3"])
+        dest_ops.apply(v, "names")
+        self.assertEqual(v.names, {'a': '1', 'b': '2', 'c': '3'})
+        self.assertTrue(v.names._is_patch)
+
+        v.items = assign_aaz_dict_arg(v.items, v.names, element_transformer=lambda _, name: {"name": name})
+        self.assertTrue(v.items._is_patch)
+        self.assertEqual(v.items, {'a': {"name": '1'}, 'b': {"name": '2'}, 'c': {"name": "3"}})
