@@ -29,7 +29,9 @@ from azure.cli.core.commands.client_factory import get_subscription_id
 
 from ._client_factory import cf_acr_registries
 from ._constants import get_managed_sku
+from ._constants import ACR_AUDIENCE_RESOURCE_NAME
 from ._utils import get_registry_by_name, ResourceNotFound
+from .policy import acr_config_authentication_as_arm_show
 from ._format import add_timestamp
 
 
@@ -37,7 +39,7 @@ logger = get_logger(__name__)
 
 
 EMPTY_GUID = '00000000-0000-0000-0000-000000000000'
-ALLOWED_HTTP_METHOD = ['get', 'patch', 'put', 'delete']
+ALLOWED_HTTP_METHOD = ['get', 'patch', 'put', 'delete', 'post']
 AAD_TOKEN_BASE_ERROR_MESSAGE = "Unable to get AAD authorization tokens with message"
 ADMIN_USER_BASE_ERROR_MESSAGE = "Unable to get admin user credentials with message"
 ALLOWS_BASIC_AUTH = "allows_basic_auth"
@@ -47,10 +49,18 @@ class RepoAccessTokenPermission(Enum):
     METADATA_READ = 'metadata_read'
     METADATA_WRITE = 'metadata_write'
     DELETE = 'delete'
+    DELETED_READ = 'deleted_read'
+    DELETED_RESTORE = 'deleted_restore'
+    PULL = 'pull'
     META_WRITE_META_READ = '{},{}'.format(METADATA_WRITE, METADATA_READ)
     DELETE_META_READ = '{},{}'.format(DELETE, METADATA_READ)
-    PULL = 'pull'
     PULL_META_READ = '{},{}'.format(PULL, METADATA_READ)
+    DELETED_READ_RESTORE = '{},{}'.format(DELETED_READ, DELETED_RESTORE)
+
+
+class RegistryAccessTokenPermission(Enum):
+    CATALOG = 'catalog'
+    DELETED_CATALOG = 'deleted_catalog'
 
 
 class HelmAccessTokenPermission(Enum):
@@ -123,16 +133,23 @@ def _get_aad_token_after_challenge(cli_ctx,
                                    repository,
                                    artifact_repository,
                                    permission,
-                                   is_diagnostics_context):
+                                   is_diagnostics_context,
+                                   use_acr_audience):
     authurl = urlparse(token_params['realm'])
     authhost = urlunparse((authurl[0], authurl[1], '/oauth2/exchange', '', '', ''))
 
     from azure.cli.core._profile import Profile
     profile = Profile(cli_ctx=cli_ctx)
 
+    scope = None
+    if use_acr_audience:
+        logger.debug("Using ACR audience token for authentication")
+        scope = "https://{}.azure.net".format(ACR_AUDIENCE_RESOURCE_NAME)
+
     # this might be a cross tenant scenario, so pass subscription to get_raw_token
     subscription = get_subscription_id(cli_ctx)
-    creds, _, tenant = profile.get_raw_token(subscription=subscription)
+    creds, _, tenant = profile.get_raw_token(subscription=subscription,
+                                             resource=scope)
 
     headers = {'Content-Type': 'application/x-www-form-urlencoded'}
     content = {
@@ -164,9 +181,8 @@ def _get_aad_token_after_challenge(cli_ctx,
     elif artifact_repository:
         scope = 'artifact-repository:{}:{}'.format(artifact_repository, permission)
     else:
-        # catalog only has * as permission, even for a read operation
-        scope = 'registry:catalog:*'
-
+        # Registry level permissions only have * as permission, even for a read operation
+        scope = 'registry:{}:*'.format(permission)
     content = {
         'grant_type': 'refresh_token',
         'service': login_server,
@@ -194,7 +210,8 @@ def _get_aad_token(cli_ctx,
                    repository=None,
                    artifact_repository=None,
                    permission=None,
-                   is_diagnostics_context=False):
+                   is_diagnostics_context=False,
+                   use_acr_audience=False):
     """Obtains refresh and access tokens for an AAD-enabled registry.
     :param str login_server: The registry login server URL to log in to
     :param bool only_refresh_token: Whether to ask for only refresh token, or for both refresh and access tokens
@@ -205,7 +222,6 @@ def _get_aad_token(cli_ctx,
     token_params = _handle_challenge_phase(
         login_server, repository, artifact_repository, permission, True, is_diagnostics_context
     )
-
     from ._errors import ErrorClass
     if isinstance(token_params, ErrorClass):
         if is_diagnostics_context:
@@ -219,7 +235,8 @@ def _get_aad_token(cli_ctx,
                                           repository,
                                           artifact_repository,
                                           permission,
-                                          is_diagnostics_context)
+                                          is_diagnostics_context,
+                                          use_acr_audience)
 
 
 def _get_token_with_username_and_password(login_server,
@@ -260,8 +277,8 @@ def _get_token_with_username_and_password(login_server,
     elif artifact_repository:
         scope = 'artifact-repository:{}:{}'.format(artifact_repository, permission)
     else:
-        # catalog only has * as permission, even for a read operation
-        scope = 'registry:catalog:*'
+        # Registry level permissions only have * as permission, even for a read operation
+        scope = 'registry:{}:*'.format(permission)
 
     authurl = urlparse(token_params['realm'])
     authhost = urlunparse((authurl[0], authurl[1], '/oauth2/token', '', '', ''))
@@ -374,8 +391,19 @@ def _get_credentials(cmd,  # pylint: disable=too-many-statements
     if not registry or registry.sku.name in get_managed_sku(cmd):
         logger.info("Attempting to retrieve AAD refresh token...")
         try:
-            return login_server, EMPTY_GUID, _get_aad_token(
-                cli_ctx, login_server, only_refresh_token, repository, artifact_repository, permission)
+            use_acr_audience = False
+
+            if registry:
+                aad_auth_policy = acr_config_authentication_as_arm_show(cmd, registry_name, resource_group_name)
+                use_acr_audience = (aad_auth_policy and aad_auth_policy.status == 'disabled')
+
+            return login_server, EMPTY_GUID, _get_aad_token(cli_ctx,
+                                                            login_server,
+                                                            only_refresh_token,
+                                                            repository,
+                                                            artifact_repository,
+                                                            permission,
+                                                            use_acr_audience=use_acr_audience)
         except CLIError as e:
             logger.warning("%s: %s", AAD_TOKEN_BASE_ERROR_MESSAGE, str(e))
 
