@@ -70,6 +70,32 @@ type: group
 short-summary: Manage content-trust policy for Azure Container Registries.
 """
 
+helps['acr config authentication-as-arm'] = """
+type: group
+short-summary: Manage 'Azure AD authenticate as ARM' policy for Azure Container Registries.
+"""
+
+helps['acr config authentication-as-arm show'] = """
+type: command
+short-summary: Show the configured 'Azure AD authenticate as ARM' policy for an Azure Container Registry.
+examples:
+  - name: Show the configured 'Azure AD authenticate as ARM' policy for an Azure Container Registry
+    text: >
+        az acr config authentication-as-arm show -r MyRegistry
+"""
+
+helps['acr config authentication-as-arm update'] = """
+type: command
+short-summary: Update 'Azure AD authenticate as ARM' policy for an Azure Container Registry.
+examples:
+  - name: Disable 'Azure AD authenticate as ARM' policy for an Azure Container Registry, so only ACR audienced tokens can be used for authentication
+    text: >
+        az acr config authentication-as-arm update -r MyRegistry --status Disabled
+  - name: Enable 'Azure AD authenticate as ARM' policy for an Azure Container Registry, it will allow both ACR and ARM audienced tokens to be used for authentication
+    text: >
+        az acr config authentication-as-arm update -r MyRegistry --status Enabled
+"""
+
 helps['acr config content-trust show'] = """
 type: command
 short-summary: Show the configured content-trust policy for an Azure Container Registry.
@@ -114,6 +140,29 @@ examples:
         az acr config retention update -r MyRegistry --status Enabled --days 0 --type UntaggedManifests
 """
 
+helps['acr config soft-delete'] = """
+type: group
+short-summary: Manage soft-delete policy for Azure Container Registries.
+"""
+
+helps['acr config soft-delete show'] = """
+type: command
+short-summary: Show the configured soft-delete policy for an Azure Container Registry.
+examples:
+  - name: Show the configured soft-delete policy for an Azure Container Registry
+    text: >
+        az acr config soft-delete show -r myregistry
+"""
+
+helps['acr config soft-delete update'] = """
+type: command
+short-summary: Update soft-delete policy for an Azure Container Registry.
+examples:
+  - name: Enable soft-delete policy for an Azure Container Registry to purge a soft-deleted manifest after 30 days.
+    text: >
+        az acr config soft-delete update -r myregistry --status Enabled --days 30
+"""
+
 helps['acr create'] = """
 type: command
 short-summary: Create an Azure Container Registry.
@@ -435,6 +484,14 @@ examples:
     text: az acr repository list -n MyRegistry
 """
 
+helps['acr repository list-deleted'] = """
+type: command
+short-summary: List soft-deleted repositories in an Azure Container Registry.
+examples:
+  - name: List soft-deleted repositories in a given Azure Container Registry.
+    text: az acr repository list-deleted -n MyRegistry
+"""
+
 helps['acr repository show'] = """
 type: command
 short-summary: Get the attributes of a repository or image in an Azure Container Registry.
@@ -504,7 +561,7 @@ examples:
   - name: Get the manifest of the artifact 'hello-world:latest'.
     text: az acr manifest show -r MyRegistry -n hello-world:latest
   - name: Get the manifest of the artifact 'hello-world:latest'.
-    text: az acr manifest show MyRegistry.azurecr.io/hello-world:latest
+    text: az acr manifest show myregistry.azurecr.io/hello-world:latest
   - name: Get the manifest of the artifact referenced by digest 'hello-world@sha256:abc123'.
     text: az acr manifest show -r MyRegistry -n hello-world@sha256:abc123
   - name: Get the raw, unformatted manifest of the artifact 'hello-world:latest'.
@@ -518,7 +575,7 @@ examples:
   - name: List the manifests of the repository 'hello-world'.
     text: az acr manifest list -r MyRegistry -n hello-world
   - name: List the manifests of the repository 'hello-world'.
-    text: az acr manifest list MyRegistry.azurecr.io/hello-world
+    text: az acr manifest list myregistry.azurecr.io/hello-world
 """
 
 helps['acr manifest delete'] = """
@@ -528,7 +585,7 @@ examples:
   - name: Delete the manifest of the artifact 'hello-world:latest'.
     text: az acr manifest delete -r MyRegistry -n hello-world:latest
   - name: Delete the manifest of the artifact 'hello-world:latest'.
-    text: az acr manifest delete MyRegistry.azurecr.io/hello-world:latest
+    text: az acr manifest delete myregistry.azurecr.io/hello-world:latest
   - name: Delete the manifest of the artifact referenced by digest 'hello-world@sha256:abc123'.
     text: az acr manifest delete -r MyRegistry -n hello-world@sha256:abc123
 """
@@ -540,16 +597,11 @@ examples:
   - name: List the referrers to the manifest of the artifact 'hello-world:latest'.
     text: az acr manifest list-referrers -r MyRegistry -n hello-world:latest
   - name: List the referrers to the manifest of the artifact 'hello-world:latest'.
-    text: az acr manifest list-referrers MyRegistry.azurecr.io/hello-world:latest
+    text: az acr manifest list-referrers myregistry.azurecr.io/hello-world:latest
   - name: List the referrers to the manifest of the artifact referenced by digest 'hello-world@sha256:abc123'.
     text: az acr manifest list-referrers -r MyRegistry -n hello-world@sha256:abc123
 """
 
-helps['acr manifest metadata'] = """
-type: group
-short-summary: Manage artifact manifest metadata in Azure Container Registries.
-"""
-
 helps['acr manifest show-metadata'] = """
 type: command
 short-summary: Get the metadata of an artifact in an Azure Container Registry.
@@ -557,7 +609,7 @@ examples:
   - name: Get the metadata of the tag 'hello-world:latest'.
     text: az acr manifest show-metadata -r MyRegistry -n hello-world:latest
   - name: Get the metadata of the tag 'hello-world:latest'.
-    text: az acr manifest show-metadata MyRegistry.azurecr.io/hello-world:latest
+    text: az acr manifest show-metadata myregistry.azurecr.io/hello-world:latest
   - name: Get the metadata of the manifest referenced by digest 'hello-world@sha256:abc123'.
     text: az acr manifest show-metadata -r MyRegistry -n hello-world@sha256:abc123
 """
@@ -569,7 +621,7 @@ examples:
   - name: List the metadata of the manifests in the repository 'hello-world'.
     text: az acr manifest list-metadata -r MyRegistry -n hello-world
   - name: List the metadata of the manifests in the repository 'hello-world'.
-    text: az acr manifest list-metadata MyRegistry.azurecr.io/hello-world
+    text: az acr manifest list-metadata myregistry.azurecr.io/hello-world
 """
 
 helps['acr manifest update-metadata'] = """
@@ -579,11 +631,17 @@ examples:
   - name: Update the metadata of the tag 'hello-world:latest'.
     text: az acr manifest update-metadata -r MyRegistry -n hello-world:latest --write-enabled false
   - name: Update the metadata of the tag 'hello-world:latest'.
-    text: az acr manifest update-metadata MyRegistry.azurecr.io/hello-world:latest --write-enabled false
+    text: az acr manifest update-metadata myregistry.azurecr.io/hello-world:latest --write-enabled false
   - name: Update the metadata of the artifact referenced by digest 'hello-world@sha256:abc123'.
     text: az acr manifest update-metadata -r MyRegistry -n hello-world@sha256:abc123 --write-enabled false
 """
 
+# Deprecated
+helps['acr manifest metadata'] = """
+type: group
+short-summary: Manage artifact manifest metadata in Azure Container Registries.
+"""
+
 helps['acr manifest metadata show'] = """
 type: command
 short-summary: Get the metadata of an artifact in an Azure Container Registry.
@@ -599,6 +657,44 @@ type: command
 short-summary: Update the manifest metadata of an artifact in an Azure Container Registry.
 """
 
+helps['acr manifest list-deleted'] = """
+type: command
+short-summary: List the soft-deleted manifests in a repository in an Azure Container Registry.
+examples:
+  - name: List the soft-deleted manifests in the repository 'hello-world'.
+    text: az acr manifest list-deleted -r MyRegistry -n hello-world
+  - name: List the soft-deleted manifests in the repository 'hello-world'.
+    text: az acr manifest list-deleted myregistry.azurecr.io/hello-world
+"""
+
+helps['acr manifest list-deleted-tags'] = """
+type: command
+short-summary: List the soft-deleted tags in a repository in an Azure Container Registry.
+examples:
+  - name: List the soft-deleted tags in the repository 'hello-world'.
+    text: az acr manifest list-deleted-tags -r MyRegistry -n hello-world
+  - name: List the soft-deleted tags in the repository 'hello-world'.
+    text: az acr manifest list-deleted-tags myregistry.azurecr.io/hello-world
+  - name: List the soft-deleted tags that match tag 'latest' in the repository 'hello-world'.
+    text: az acr manifest list-deleted-tags -r MyRegistry -n hello-world:latest
+  - name: List the soft-deleted tags that match tag 'latest' in the repository 'hello-world'.
+    text: az acr manifest list-deleted-tags myregistry.azurecr.io/hello-world:latest
+"""
+
+helps['acr manifest restore'] = """
+type: command
+short-summary: Restore a soft-deleted artifact and tag in an Azure Container Registry.
+examples:
+  - name: Restore the manifest matching digest 'sha256:abc123' with tag 'latest' in the repository 'hello-world'.
+    text: az acr manifest restore -r MyRegistry -n hello-world:latest -d sha256:abc123
+  - name: Restore the manifest matching digest 'sha256:abc123' with tag 'latest' in the repository 'hello-world'.
+    text: az acr manifest restore myregistry.azurecr.io/hello-world:latest -d sha256:abc123
+  - name: Restore the most recently deleted manifest associated with the tag 'latest' in the repository 'hello-world'.
+    text: az acr manifest restore -r MyRegistry -n hello-world:latest
+  - name: Restore the most recently deleted manifest associated with the tag 'latest' in the repository 'hello-world'.
+    text: az acr manifest restore myregistry.azurecr.io/hello-world:latest
+"""
+
 helps['acr run'] = """
 type: command
 short-summary: Queues a quick run providing streamed logs for an Azure Container Registry.
