@@ -480,6 +480,7 @@ def aks_create(
     aks_custom_headers=None,
     host_group_id=None,
     gpu_instance_profile=None,
+    enable_syslog=False,
 ):
     # DO NOT MOVE: get all the original parameters and save them as a dictionary
     raw_parameters = locals()
@@ -775,7 +776,8 @@ def aks_disable_addons(cmd, client, resource_group_name, name, addons, no_wait=F
                 remove_monitoring=True,
                 aad_route=True,
                 create_dcr=False,
-                create_dcra=True
+                create_dcra=True,
+                enable_syslog=False,
             )
     except TypeError:
         pass
@@ -808,7 +810,8 @@ def aks_enable_addons(cmd, client, resource_group_name, name, addons,
                       enable_secret_rotation=False,
                       rotation_poll_interval=None,
                       no_wait=False,
-                      enable_msi_auth_for_monitoring=False):
+                      enable_msi_auth_for_monitoring=False,
+                      enable_syslog=False):
     instance = client.get(resource_group_name, name)
     msi_auth = False
     if instance.service_principal_profile.client_id == "msi":
@@ -827,7 +830,8 @@ def aks_enable_addons(cmd, client, resource_group_name, name, addons,
                               enable_sgxquotehelper=enable_sgxquotehelper,
                               enable_secret_rotation=enable_secret_rotation,
                               rotation_poll_interval=rotation_poll_interval,
-                              no_wait=no_wait)
+                              no_wait=no_wait,
+                              enable_syslog=enable_syslog)
 
     enable_monitoring = CONST_MONITORING_ADDON_NAME in instance.addon_profiles \
         and instance.addon_profiles[CONST_MONITORING_ADDON_NAME].enabled
@@ -855,12 +859,16 @@ def aks_enable_addons(cmd, client, resource_group_name, name, addons,
                         instance.location,
                         aad_route=True,
                         create_dcr=True,
-                        create_dcra=True)
+                        create_dcra=True,
+                        enable_syslog=enable_syslog)
                 else:
                     raise ArgumentUsageError(
                         "--enable-msi-auth-for-monitoring can not be used on clusters with service principal auth.")
             else:
                 # monitoring addon will use legacy path
+                if enable_syslog:
+                    raise ArgumentUsageError(
+                        "--enable-syslog can not be used without MSI auth.")
                 ensure_container_insights_for_monitoring(
                     cmd, instance.addon_profiles[CONST_MONITORING_ADDON_NAME], subscription_id, resource_group_name, name, instance.location, aad_route=False)
 
@@ -914,7 +922,8 @@ def _update_addons(cmd, instance, subscription_id, resource_group_name, name, ad
                    enable_secret_rotation=False,
                    disable_secret_rotation=False,
                    rotation_poll_interval=None,
-                   no_wait=False):
+                   no_wait=False,
+                   enable_syslog=False):
     ManagedClusterAddonProfile = cmd.get_models('ManagedClusterAddonProfile',
                                                 resource_type=ResourceType.MGMT_CONTAINERSERVICE,
                                                 operation_group='managed_clusters')
