@@ -13,7 +13,8 @@ from azure.cli.command_modules.appservice.static_sites import \
     set_staticsite_app_settings, delete_staticsite_app_settings, list_staticsite_users, \
     invite_staticsite_users, update_staticsite_users, update_staticsite, list_staticsite_secrets, \
     reset_staticsite_api_key, delete_staticsite_environment, link_user_function, unlink_user_function, get_user_function, \
-    assign_identity, remove_identity, show_identity, enable_staticwebapp_enterprise_edge, disable_staticwebapp_enterprise_edge, show_staticwebapp_enterprise_edge_status
+    assign_identity, remove_identity, show_identity, enable_staticwebapp_enterprise_edge, disable_staticwebapp_enterprise_edge, \
+    show_staticwebapp_enterprise_edge_status, validate_backend, link_backend, get_backend, unlink_backend
 from azure.core.exceptions import ResourceNotFoundError
 
 
@@ -125,6 +126,27 @@ class TestStaticAppCommands(unittest.TestCase):
         self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
 
 
+    @mock.patch('azure.cli.core.util', autospec=True)
+    def test_create_staticapp_azure_devops(self, util):
+        from azure.mgmt.web.models import StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
+        self.mock_cmd.get_models.return_value = StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
+
+        with mock.patch("azure.cli.command_modules.appservice.static_sites.show_staticsite", side_effect=[ResourceNotFoundError("msg"), None]):
+            with mock.patch('azure.cli.command_modules.appservice.static_sites._get_ado_token', autospec=True):
+                create_staticsites(
+                    self.mock_cmd, self.rg1, self.name1, self.location1,
+                    self.source_ado, self.branch1, login_with_ado=True)
+
+        self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
+        arg_list = self.staticapp_client.begin_create_or_update_static_site.call_args[1]
+        self.assertEqual(self.name1, arg_list["name"])
+        self.assertEqual(self.rg1, arg_list["resource_group_name"])
+        self.assertEqual(self.location1, arg_list["static_site_envelope"].location)
+        self.assertEqual(self.source_ado, arg_list["static_site_envelope"].repository_url)
+        self.assertEqual(self.branch1, arg_list["static_site_envelope"].branch)
+        self.assertEqual('Free', arg_list["static_site_envelope"].sku.name)
+
+
     def test_create_staticapp_with_standard_sku(self):
         from azure.mgmt.web.models import StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
         self.mock_cmd.get_models.return_value = StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
@@ -612,6 +634,35 @@ class TestStaticAppCommands(unittest.TestCase):
 
         self.staticapp_client.get_user_provided_function_apps_for_static_site.assert_called_once()
 
+    def test_backends_validate(self, *args, **kwargs):
+        backend_name = "backend"
+        backend_resource_id = "/subscriptions/sub/resourceGroups/{}/providers/Microsoft.App/containerApps/{}".format(
+            self.rg1, backend_name
+        )
+        validate_backend(self.mock_cmd, self.name1, self.rg1, backend_resource_id)
+
+        self.staticapp_client.begin_validate_backend_for_build.assert_called_once()
+
+    def test_backends_link(self, *args, **kwargs):
+        backend_name = "backend"
+        backend_resource_id = "/subscriptions/sub/resourceGroups/{}/providers/Microsoft.Web/sites/{}".format(
+            self.rg1, backend_name
+        )
+        link_backend(self.mock_cmd, self.name1, self.rg1, backend_resource_id)
+
+        self.staticapp_client.begin_link_backend_to_build.assert_called_once()
+
+    @mock.patch("azure.cli.command_modules.appservice.static_sites.get_backend", return_value=[mock.MagicMock()])
+    def test_backends_unlink(self, *args, **kwargs):
+        unlink_backend(self.mock_cmd, self.name1, self.rg1)
+
+        self.staticapp_client.unlink_backend_from_build.assert_called_once()
+
+    def test_backends_show(self, *args, **kwargs):
+        get_backend(self.mock_cmd, self.name1, self.rg1)
+
+        self.staticapp_client.get_linked_backends_for_build.assert_called_once()
+
     def test_enterprise_edge(self):
         self.staticapp_client.get_static_site.return_value = self.app1
 
@@ -652,6 +703,7 @@ def _set_up_fake_apps(self):
     self.name1_not_exist = 'name1_not_exist'
     self.location1 = 'location1'
     self.source1 = 'https://github.com/Contoso/My-First-Static-App'
+    self.source_ado = ' https://dev.azure.com/username/Test/_git/Test'
     self.branch1 = 'dev'
     self.token1 = 'TOKEN_1'
     self.environment1 = 'default'
