@@ -7,6 +7,7 @@ from azure.cli.command_modules.aro._validators import validate_cidr
 from azure.cli.command_modules.aro._validators import validate_client_id
 from azure.cli.command_modules.aro._validators import validate_client_secret
 from azure.cli.command_modules.aro._validators import validate_cluster_resource_group
+from azure.cli.command_modules.aro._validators import validate_disk_encryption_set
 from azure.cli.command_modules.aro._validators import validate_domain
 from azure.cli.command_modules.aro._validators import validate_pull_secret
 from azure.cli.command_modules.aro._validators import validate_subnet
@@ -15,8 +16,9 @@ from azure.cli.command_modules.aro._validators import validate_vnet
 from azure.cli.command_modules.aro._validators import validate_vnet_resource_group_name
 from azure.cli.command_modules.aro._validators import validate_worker_count
 from azure.cli.command_modules.aro._validators import validate_worker_vm_disk_size_gb
+from azure.cli.command_modules.aro._validators import validate_refresh_cluster_credentials
 from azure.cli.core.commands.parameters import name_type
-from azure.cli.core.commands.parameters import get_enum_type
+from azure.cli.core.commands.parameters import get_enum_type, get_three_state_flag
 from azure.cli.core.commands.parameters import resource_group_name_type
 from azure.cli.core.commands.parameters import tags_type
 from azure.cli.core.commands.validators import get_default_location_from_resource_group
@@ -41,24 +43,36 @@ def load_arguments(self, _):
         c.argument('cluster_resource_group',
                    help='Resource group of cluster.',
                    validator=validate_cluster_resource_group)
+        c.argument('fips_validated_modules', arg_type=get_three_state_flag(),
+                   options_list=['--fips-validated-modules', '--fips'],
+                   help='Use FIPS validated cryptography modules.')
 
         c.argument('client_id',
                    help='Client ID of cluster service principal.',
                    validator=validate_client_id)
         c.argument('client_secret',
                    help='Client secret of cluster service principal.',
-                   validator=validate_client_secret)
+                   validator=validate_client_secret(isCreate=True))
 
         c.argument('pod_cidr',
-                   help='CIDR of pod network.',
+                   help='CIDR of pod network. Must be a minimum of /18 or larger.',
                    validator=validate_cidr('pod_cidr'))
         c.argument('service_cidr',
-                   help='CIDR of service network.',
+                   help='CIDR of service network. Must be a minimum of /18 or larger.',
                    validator=validate_cidr('service_cidr'))
 
+        c.argument('disk_encryption_set',
+                   help='ResourceID of the DiskEncryptionSet to be used for master and worker VMs.',
+                   validator=validate_disk_encryption_set)
+        c.argument('master_encryption_at_host', arg_type=get_three_state_flag(),
+                   options_list=['--master-encryption-at-host', '--master-enc-host'],
+                   help='Encryption at host flag for master VMs.')
         c.argument('master_vm_size',
                    help='Size of master VMs.')
 
+        c.argument('worker_encryption_at_host', arg_type=get_three_state_flag(),
+                   options_list=['--worker-encryption-at-host', '--worker-enc-host'],
+                   help='Encryption at host flag for worker VMs.')
         c.argument('worker_vm_size',
                    help='Size of worker VMs.')
         c.argument('worker_vm_disk_size_gb',
@@ -92,3 +106,12 @@ def load_arguments(self, _):
         c.argument('worker_subnet',
                    help='Name or ID of worker vnet subnet.  If name is supplied, `--vnet` must be supplied.',
                    validator=validate_subnet('worker_subnet'))
+    with self.argument_context('aro update') as c:
+        c.argument('client_secret',
+                   help='Client secret of cluster service principal.',
+                   validator=validate_client_secret(isCreate=False))
+        c.argument('refresh_cluster_credentials',
+                   arg_type=get_three_state_flag(),
+                   help='Refresh cluster application credentials.',
+                   options_list=['--refresh-credentials'],
+                   validator=validate_refresh_cluster_credentials)
