@@ -66,7 +66,7 @@ parameters:
 examples:
   - name: Create a new action group (autogenerated)
     text: |
-        az monitor action-group create --action webhook https://alerts.contoso.com apiKey={APIKey} type=HighCPU --name MyActionGroup --resource-group MyResourceGroup
+        az monitor action-group create --action webhook MyActionName https://alerts.contoso.com apiKey={APIKey} type=HighCPU --name MyActionGroup --resource-group MyResourceGroup
     crafted: true
 """
 
@@ -843,92 +843,6 @@ type: command
 short-summary: Update diagnostic settings for a subscription.
 """
 
-helps['monitor log-analytics'] = """
-type: group
-short-summary: Manage Azure log analytics.
-"""
-
-helps['monitor log-analytics cluster'] = """
-type: group
-short-summary: Manage Azure log analytics cluster.
-"""
-
-helps['monitor log-analytics cluster create'] = """
-type: command
-short-summary: Create a cluster instance.
-examples:
-  - name: Create a cluster instance.
-    text: az monitor log-analytics cluster create -g MyResourceGroup -n MyCluster --sku-capacity 1000
-"""
-
-helps['monitor log-analytics cluster wait'] = """
-type: command
-short-summary: Place the CLI in a waiting state until a condition of the cluster is met.
-examples:
-  - name: Pause executing next line of CLI script until the cluster is successfully provisioned.
-    text: az monitor log-analytics cluster wait -n MyCluster -g MyResourceGroup --created
-"""
-
-helps['monitor log-analytics workspace'] = """
-type: group
-short-summary: Manage Azure log analytics workspace
-"""
-
-helps['monitor log-analytics workspace create'] = """
-type: command
-short-summary: Create a workspace instance
-examples:
-  - name: Create a workspace instance
-    text: az monitor log-analytics workspace create -g MyResourceGroup -n MyWorkspace
-"""
-
-helps['monitor log-analytics workspace delete'] = """
-type: command
-short-summary: Delete a workspace instance.
-examples:
-  - name: Delete a workspace instance. (autogenerated)
-    text: |
-        az monitor log-analytics workspace delete --force true --resource-group MyResourceGroup --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace get-schema'] = """
-type: command
-short-summary: Get the schema for a given workspace.
-long-summary: >
-    Schema represents the internal structure of the workspace, which can be used during the query.
-    For more information, visit: https://docs.microsoft.com/rest/api/loganalytics/workspaces%202015-03-20/getschema
-examples:
-  - name: Get the schema for a given workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace get-schema --resource-group MyResourceGroup --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace get-shared-keys'] = """
-type: command
-short-summary: Get the shared keys for a workspace.
-examples:
-  - name: Get the shared keys for a workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace get-shared-keys --resource-group MyResourceGroup --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace list'] = """
-type: command
-short-summary: Get a list of workspaces under a resource group or a subscription.
-"""
-
-helps['monitor log-analytics workspace list-deleted-workspaces'] = """
-type: command
-short-summary: Get a list of deleted workspaces that can be recovered in a subscription or a resource group.
-examples:
-  - name: Get a list of deleted workspaces that can be recovered in a resource group
-    text: |
-        az monitor log-analytics workspace list-deleted-workspaces --resource-group MyResourceGroup
-"""
-
 helps['monitor log-analytics workspace recover'] = """
 type: command
 short-summary: Recover a workspace in a soft-delete state within 14 days.
@@ -938,49 +852,11 @@ examples:
         az monitor log-analytics workspace recover --resource-group MyResourceGroup -n MyWorkspace
 """
 
-helps['monitor log-analytics workspace list-management-groups'] = """
-type: command
-short-summary: Get a list of management groups connected to a workspace.
-examples:
-  - name: Get a list of management groups connected to a workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace list-management-groups --resource-group MyResourceGroup --subscription mysubscription --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace list-usages'] = """
-type: command
-short-summary: Get a list of usage metrics for a workspace.
-examples:
-  - name: Get a list of usage metrics for a workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace list-usages --resource-group MyResourceGroup --subscription MySubscription --workspace-name MyWorkspace
-    crafted: true
-"""
-
 helps['monitor log-analytics workspace table'] = """
 type: group
 short-summary: Manage tables for log analytics workspace.
 """
 
-helps['monitor log-analytics workspace table list'] = """
-type: command
-short-summary: List all the tables for the given Log Analytics workspace.
-examples:
-  - name: List all the tables for the given Log Analytics workspace
-    text: |
-        az monitor log-analytics workspace table list --resource-group MyResourceGroup --workspace-name MyWorkspace
-"""
-
-helps['monitor log-analytics workspace table show'] = """
-type: command
-short-summary: Get a Log Analytics workspace table.
-examples:
-  - name: Get a Log Analytics workspace table
-    text: |
-        az monitor log-analytics workspace table show --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable
-"""
-
 helps['monitor log-analytics workspace table create'] = """
 type: command
 short-summary: Create a Log Analytics workspace microsoft/custom log table. The table name needs to end with '_CL'.
@@ -990,15 +866,6 @@ examples:
         az monitor log-analytics workspace table create --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_CL --retention-time 45 --columns MyColumn1=string TimeGenerated=datetime
 """
 
-helps['monitor log-analytics workspace table migrate'] = """
-type: command
-short-summary: Migrate a Log Analytics table from support of the Data Collector API and Custom Fields features to support of Data Collection Rule-based Custom Logs.
-examples:
-  - name: Migrate a Log Analytics workspace table.
-    text: |
-        az monitor log-analytics workspace table migrate --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_CL
-"""
-
 helps['monitor log-analytics workspace table search-job'] = """
 type: group
 short-summary: Manage tables for log analytics workspace search results table.
@@ -1027,7 +894,6 @@ examples:
         az monitor log-analytics workspace table restore create --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_RST --start-restore-time "Sat, 28 Aug 2021 05:29:18 GMT" --end-restore-time "Sat, 28 Aug 2021 08:29:18 GMT" --restore-source-table MyTable
 """
 
-
 helps['monitor log-analytics workspace table update'] = """
 type: command
 short-summary: Update the properties of a Log Analytics workspace table.
@@ -1037,163 +903,20 @@ examples:
         az monitor log-analytics workspace table update --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable --retention-time 30
 """
 
-helps['monitor log-analytics workspace table delete'] = """
+helps['monitor log-analytics workspace saved-search create'] = """
 type: command
-short-summary: Delete a Log Analytics workspace table.
+short-summary: Create a saved search for a given workspace.
 examples:
-  - name: Delete a Log Analytics workspace table.
-    text: |
-        az monitor log-analytics workspace table delete --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable
+  - name: Create a saved search for a given workspace.
+    text: az monitor log-analytics workspace saved-search create -g MyRG --workspace-name MyWS -n MySavedSearch --category Test1 --display-name TestSavedSearch -q "AzureActivity | summarize count() by bin(TimeGenerated, 1h)" --fa myfun --fp "a:string = value"
 """
 
-helps['monitor log-analytics workspace table wait'] = """
+helps['monitor log-analytics workspace saved-search update'] = """
 type: command
-short-summary: Place the CLI in a waiting state until a condition of the workspace table is met.
+short-summary: Update a saved search for a given workspace.
 examples:
-  - name: Pause executing next line of CLI script until the workspace table is successfully provisioned.
-    text: az monitor log-analytics workspace table wait -n MyTable -g MyResourceGroup --workspace-name MyWorkspace --created
-"""
-
-helps['monitor log-analytics workspace pack'] = """
-type: group
-short-summary: Manage intelligent packs for log analytics workspace.
-"""
-
-helps['monitor log-analytics workspace pack disable'] = """
-type: command
-short-summary: Disable an intelligence pack for a given workspace.
-"""
-
-helps['monitor log-analytics workspace pack enable'] = """
-type: command
-short-summary: Enable an intelligence pack for a given workspace.
-examples:
-  - name: Enable an intelligence pack for a given workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace pack enable --name MyIntelligencePack --resource-group MyResourceGroup --subscription mysubscription --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace pack list'] = """
-type: command
-short-summary: List all the intelligence packs possible and whether they are enabled or disabled for a given workspace.
-examples:
-  - name: List all the intelligence packs possible and whether they are enabled or disabled for a given workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace pack list --resource-group MyResourceGroup --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace show'] = """
-type: command
-short-summary: Show a workspace instance.
-examples:
-  - name: Show a workspace instance. (autogenerated)
-    text: |
-        az monitor log-analytics workspace show --resource-group MyResourceGroup --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace update'] = """
-type: command
-short-summary: Update a workspace instance
-examples:
-  - name: Update a workspace instance. (autogenerated)
-    text: |
-        az monitor log-analytics workspace update --resource-group myresourcegroup --retention-time 30 --workspace-name myworkspace
-    crafted: true
-  - name: Update the defaultDataCollectionRuleResourceId of the workspace
-    text: |
-        az monitor log-analytics workspace update --resource-group myresourcegroup --workspace-name myworkspace --data-collection-rule "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/dataCollectionRules/{dcrName}".
-"""
-
-helps['monitor log-analytics workspace linked-service'] = """
-type: group
-short-summary: Manage linked service for log analytics workspace.
-long-summary: |
-    Linked services is used to defined a relation from the workspace to another Azure resource. Log Analytics and Azure resources then leverage this connection in their operations. Example uses of Linked Services in Log Analytics workspace are Automation account and workspace association to CMK.
-"""
-
-helps['monitor log-analytics workspace linked-service create'] = """
-type: command
-short-summary: Create a linked service.
-examples:
-  - name: Create a linked service.
-    text: |
-        az monitor log-analytics workspace linked-service create -g MyResourceGroup -n cluster \\
-          --workspace-name MyWorkspace --write-access-resource-id /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/MyResourceGroup/providers/Microsoft.OperationalInsights/clusters/MyCluster
-"""
-
-helps['monitor log-analytics workspace linked-service update'] = """
-type: command
-short-summary: Update a linked service.
-examples:
-  - name: Update a linked service.
-    text: |
-        az monitor log-analytics workspace linked-service update -g MyResourceGroup -n cluster \\
-          --workspace-name MyWorkspace --write-access-resource-id /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/MyResourceGroup/providers/Microsoft.OperationalInsights/clusters/MyCluster
-"""
-
-helps['monitor log-analytics workspace linked-service show'] = """
-type: command
-short-summary: Show the properties of a linked service.
-examples:
-  - name: Show the properties of a linked service.
-    text: |
-        az monitor log-analytics workspace linked-service show -g MyResourceGroup -n cluster --workspace-name MyWorkspace
-"""
-
-helps['monitor log-analytics workspace linked-service delete'] = """
-type: command
-short-summary: Delete a linked service.
-examples:
-  - name: Delete a linked service.
-    text: |
-        az monitor log-analytics workspace linked-service delete -g MyResourceGroup -n cluster --workspace-name MyWorkspace
-"""
-
-helps['monitor log-analytics workspace linked-service list'] = """
-type: command
-short-summary: Gets all the linked services in a workspace.
-examples:
-  - name: Gets all the linked services in a workspace.
-    text: |
-        az monitor log-analytics workspace linked-service list -g MyResourceGroup --workspace-name MyWorkspace
-"""
-
-helps['monitor log-analytics workspace linked-service wait'] = """
-type: command
-short-summary: Place the CLI in a waiting state until a condition of the linked service is met.
-examples:
-  - name: Pause executing next line of CLI script until the linked service is successfully provisioned.
-    text: az monitor log-analytics workspace linked-service wait -n cluster -g MyResourceGroup --workspace-name MyWorkspace --created
-"""
-
-helps['monitor log-analytics workspace linked-storage'] = """
-type: group
-short-summary: Manage linked storage account for log analytics workspace.
-"""
-
-helps['monitor log-analytics workspace linked-storage create'] = """
-type: command
-short-summary: Create some linked storage accounts for log analytics workspace.
-examples:
-  - name: Create two linked storage accounts for a log analytics workspace using the name of the storage account.
-    text: az monitor log-analytics workspace linked-storage create --type AzureWatson -g MyResourceGroup --workspace-name MyWorkspace --storage-accounts StorageAccount1 StorageAccount2
-  - name: Create one linked storage accounts for a log analytics workspace using the resource id of the storage account.
-    text: az monitor log-analytics workspace linked-storage create --type AzureWatson -g MyResourceGroup --workspace-name MyWorkspace --storage-accounts /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/clitest.rg000001/providers/Microsoft.Storage/storageAccounts/cli000001
-  - name: Create some linked storage accounts for log analytics workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace linked-storage create --resource-group MyResourceGroup --storage-accounts /subscriptions/00000000-0000-0000-0000-00000000000000000/resourceGroups/clitest.rg000001/providers/Microsoft.Storage/storageAccounts/cli000001 --subscription mysubscription --type CustomLogs --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace linked-storage delete'] = """
-type: command
-short-summary: Delete all linked storage accounts with specific data source type for log analytics workspace.
-examples:
-  - name: Delete all linked storage accounts with a specific type for a log analytics workspace
-    text: az monitor log-analytics workspace linked-storage delete --type AzureWatson -g MyResourceGroup --workspace-name MyWorkspace
+  - name: Update a saved search for a given workspace.
+    text: az monitor log-analytics workspace saved-search update -g MyRG --workspace-name MyWS -n MySavedSearch --category Test1 --display-name TestSavedSearch -q "AzureActivity | summarize count() by bin(TimeGenerated, 1h)" --fa myfun --fp "a:string = value"
 """
 
 helps['monitor log-analytics workspace linked-storage add'] = """
@@ -1216,112 +939,6 @@ examples:
     text: az monitor log-analytics workspace linked-storage remove --type AzureWatson -g MyResourceGroup --workspace-name MyWorkspace --storage-accounts /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/clitest.rg000001/providers/Microsoft.Storage/storageAccounts/cli000001
 """
 
-helps['monitor log-analytics workspace linked-storage list'] = """
-type: command
-short-summary: List all linked storage accounts for a log analytics workspace.
-examples:
-  - name: List all linked storage accounts for a log analytics workspace. (autogenerated)
-    text: |
-        az monitor log-analytics workspace linked-storage list --resource-group MyResourceGroup --workspace-name MyWorkspace
-    crafted: true
-"""
-
-helps['monitor log-analytics workspace linked-storage show'] = """
-type: command
-short-summary: List all linked storage accounts with specific data source type for a log analytics workspace.
-examples:
-  - name: Show all linked storage accounts with a specific type for a log analytics workspace
-    text: az monitor log-analytics workspace linked-storage show --type AzureWatson -g MyResourceGroup --workspace-name MyWorkspace
-"""
-
-helps['monitor log-analytics workspace saved-search'] = """
-type: group
-short-summary: Manage saved search for log analytics workspace.
-"""
-
-helps['monitor log-analytics workspace saved-search create'] = """
-type: command
-short-summary: Create a saved search for a given workspace.
-examples:
-  - name: Create a saved search for a given workspace.
-    text: az monitor log-analytics workspace saved-search create -g MyRG --workspace-name MyWS -n MySavedSearch --category Test1 --display-name TestSavedSearch -q "AzureActivity | summarize count() by bin(TimeGenerated, 1h)" --fa myfun --fp "a:string = value"
-"""
-
-helps['monitor log-analytics workspace saved-search update'] = """
-type: command
-short-summary: Update a saved search for a given workspace.
-examples:
-  - name: Update a saved search for a given workspace.
-    text: az monitor log-analytics workspace saved-search update -g MyRG --workspace-name MyWS -n MySavedSearch --category Test1 --display-name TestSavedSearch -q "AzureActivity | summarize count() by bin(TimeGenerated, 1h)" --fa myfun --fp "a:string = value"
-"""
-
-helps['monitor log-analytics workspace saved-search list'] = """
-type: command
-short-summary: List all saved searches for a given workspace.
-"""
-
-helps['monitor log-analytics workspace saved-search show'] = """
-type: command
-short-summary: Show a saved search for a given workspace.
-"""
-
-helps['monitor log-analytics workspace saved-search delete'] = """
-type: command
-short-summary: Delete a saved search for a given workspace.
-"""
-
-helps['monitor log-analytics workspace data-export'] = """
-type: group
-short-summary: Manage data export ruls for log analytics workspace.
-"""
-
-helps['monitor log-analytics workspace data-export create'] = """
-type: command
-short-summary: Create a data export rule for a given workspace.
-long-summary: |
-    For more information, see
-    https://docs.microsoft.com/azure/azure-monitor/platform/logs-data-export.
-parameters:
-  - name: --tables -t
-    short-summary: An array of tables to export.
-    populator-commands:
-      - "`az monitor log-analytics workspace table list`"
-examples:
-  - name: Create a data export rule for a given workspace.
-    text: az monitor log-analytics workspace data-export create -g MyRG --workspace-name MyWS -n MyDataExport --destination {sa_id_1} --enable -t {table_name}
-"""
-
-helps['monitor log-analytics workspace data-export update'] = """
-type: command
-short-summary: Update a data export rule for a given workspace.
-long-summary: |
-    For more information, see
-    https://docs.microsoft.com/azure/azure-monitor/platform/logs-data-export.
-parameters:
-  - name: --tables -t
-    short-summary: An array of tables to export.
-    populator-commands:
-      - "`az monitor log-analytics workspace table list`"
-examples:
-  - name: Update a data export rule for a given workspace.
-    text: az monitor log-analytics workspace data-export update -g MyRG --workspace-name MyWS -n MyDataExport --destination {namespace_id} -t {table_name} --enable false
-"""
-
-helps['monitor log-analytics workspace data-export list'] = """
-type: command
-short-summary: List all data export ruleses for a given workspace.
-"""
-
-helps['monitor log-analytics workspace data-export show'] = """
-type: command
-short-summary: Show a data export rule for a given workspace.
-"""
-
-helps['monitor log-analytics workspace data-export delete'] = """
-type: command
-short-summary: Delete a data export rule for a given workspace.
-"""
-
 helps['monitor log-profiles'] = """
 type: group
 short-summary: Manage log profiles.
