@@ -12,21 +12,21 @@ from azure.cli.core.commands import CliCommandType
 from azure.cli.core.profiles import get_api_version, ResourceType
 
 from azure.cli.command_modules.network._client_factory import (
-    cf_application_gateways, cf_express_route_circuit_authorizations,
-    cf_express_route_circuit_peerings, cf_express_route_circuits,
-    cf_express_route_service_providers, cf_load_balancers, cf_local_network_gateways,
-    cf_network_interfaces, cf_network_security_groups, cf_network_watcher, cf_packet_capture,
+    cf_application_gateways,
+    cf_express_route_circuits,
+    cf_load_balancers,
+    cf_network_interfaces, cf_network_watcher, cf_packet_capture,
     cf_virtual_networks, cf_virtual_network_peerings, cf_virtual_network_gateway_connections,
     cf_virtual_network_gateways,
     cf_dns_mgmt_record_sets, cf_dns_mgmt_zones,
-    cf_security_rules, cf_subnets, cf_usages,
+    cf_subnets,
     cf_public_ip_addresses, cf_connection_monitor,
     cf_public_ip_prefixes, cf_dns_references, cf_private_endpoints,
-    cf_express_route_circuit_connections, cf_express_route_gateways, cf_express_route_connections,
-    cf_express_route_ports, cf_express_route_port_locations, cf_express_route_links, cf_app_gateway_waf_policy,
-    cf_private_link_services, cf_private_endpoint_types, cf_peer_express_route_circuit_connections,
+    cf_express_route_circuit_connections,
+    cf_express_route_ports, cf_app_gateway_waf_policy,
+    cf_private_link_services, cf_private_endpoint_types,
     cf_virtual_router, cf_virtual_router_peering, cf_bastion_hosts, cf_flow_logs,
-    cf_private_dns_zone_groups, cf_load_balancer_backend_pools, cf_virtual_hub)
+    cf_private_dns_zone_groups, cf_load_balancer_backend_pools)
 from azure.cli.command_modules.network._util import (
     list_network_resource_property, get_network_resource_property_entry, delete_network_resource_property_entry,
     delete_lb_resource_property_entry)
@@ -46,7 +46,7 @@ from azure.cli.command_modules.network._validators import (
     get_network_watcher_from_location,
     process_ag_create_namespace, process_ag_http_listener_create_namespace, process_ag_listener_create_namespace, process_ag_settings_create_namespace, process_ag_http_settings_create_namespace,
     process_ag_rule_create_namespace, process_ag_routing_rule_create_namespace, process_ag_ssl_policy_set_namespace, process_ag_url_path_map_create_namespace,
-    process_ag_url_path_map_rule_create_namespace, process_auth_create_namespace, process_nic_create_namespace,
+    process_ag_url_path_map_rule_create_namespace, process_nic_create_namespace,
     process_lb_create_namespace, process_lb_frontend_ip_namespace, process_nw_cm_v2_create_namespace,
     process_nw_cm_v2_endpoint_namespace, process_nw_cm_v2_test_configuration_namespace,
     process_nw_cm_v2_test_group, process_nw_cm_v2_output_namespace,
@@ -107,65 +107,18 @@ def load_command_table(self, _):
         min_api='2016-09-01'
     )
 
-    network_er_connection_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRouteConnectionsOperations.{}',
-        client_factory=cf_express_route_connections,
-        min_api='2018-08-01'
-    )
-
-    network_er_gateway_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRouteGatewaysOperations.{}',
-        client_factory=cf_express_route_gateways,
-        min_api='2018-08-01'
-    )
-
     network_er_ports_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#ExpressRoutePortsOperations.{}',
         client_factory=cf_express_route_ports,
         min_api='2018-08-01'
     )
 
-    network_er_port_locations_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRoutePortsLocationsOperations.{}',
-        client_factory=cf_express_route_port_locations,
-        min_api='2018-08-01'
-    )
-
-    network_er_links_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRouteLinksOperations.{}',
-        client_factory=cf_express_route_links,
-        min_api='2018-08-01'
-    )
-
-    network_erca_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRouteCircuitAuthorizationsOperations.{}',
-        client_factory=cf_express_route_circuit_authorizations,
-        min_api='2016-09-01'
-    )
-
     network_erconn_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#ExpressRouteCircuitConnectionsOperations.{}',
         client_factory=cf_express_route_circuit_connections,
         min_api='2018-07-01'
     )
 
-    network_perconn_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#PeerExpressRouteCircuitConnectionsOperations.{}',
-        client_factory=cf_peer_express_route_circuit_connections,
-        min_api='2019-02-01'
-    )
-
-    network_ersp_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRouteServiceProvidersOperations.{}',
-        client_factory=cf_express_route_service_providers,
-        min_api='2016-09-01'
-    )
-
-    network_er_peering_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ExpressRouteCircuitPeeringsOperations.{}',
-        client_factory=cf_express_route_circuit_peerings
-    )
-
     network_private_endpoint_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#PrivateEndpointsOperations.{}',
         client_factory=cf_private_endpoints,
@@ -195,26 +148,11 @@ def load_command_table(self, _):
         min_api='2020-04-01'
     )
 
-    network_lgw_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#LocalNetworkGatewaysOperations.{}',
-        client_factory=cf_local_network_gateways
-    )
-
     network_nic_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#NetworkInterfacesOperations.{}',
         client_factory=cf_network_interfaces
     )
 
-    network_nsg_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#NetworkSecurityGroupsOperations.{}',
-        client_factory=cf_network_security_groups
-    )
-
-    network_nsg_rule_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#SecurityRulesOperations.{}',
-        client_factory=cf_security_rules
-    )
-
     network_public_ip_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#PublicIPAddressesOperations.{}',
         client_factory=cf_public_ip_addresses
@@ -276,18 +214,6 @@ def load_command_table(self, _):
         client_factory=cf_packet_capture
     )
 
-    network_virtual_hub_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#VirtualHubsOperations.{}',
-        client_factory=cf_virtual_hub,
-        min_api='2020-07-01'
-    )
-
-    network_virtual_hub_update_sdk = CliCommandType(
-        operations_tmpl='azure.cli.command_modules.network.custom#{}',
-        client_factory=cf_virtual_hub,
-        min_api='2020-07-01'
-    )
-
     network_vrouter_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#VirtualRoutersOperations.{}',
         client_factory=cf_virtual_router,
@@ -334,27 +260,23 @@ def load_command_table(self, _):
     # endregion
 
     # region NetworkRoot
-    usage_path = 'azure.mgmt.network.operations#UsagesOperations.{}'
-    with self.command_group('network') as g:
-        g.command('list-usages', 'list', operations_tmpl=usage_path, client_factory=cf_usages, transform=transform_network_usage_list, table_transformer=transform_network_usage_table)
+    with self.command_group('network'):
+        from azure.cli.command_modules.network.aaz.latest.network import ListUsages
+        self.command_table['network list-usages'] = ListUsages(loader=self, transform=transform_network_usage_list, table_transformer=transform_network_usage_table)
     # endregion
 
     # region ApplicationGateways
-    with self.command_group('network application-gateway', network_ag_sdk) as g:
+    with self.command_group('network application-gateway') as g:
         g.custom_command('create', 'create_application_gateway',
                          transform=DeploymentOutputLongRunningOperation(self.cli_ctx),
                          supports_no_wait=True,
                          table_transformer=deployment_validate_table_format,
                          validator=process_ag_create_namespace,
                          exception_handler=handle_template_based_exception)
-        g.command('delete', 'begin_delete', supports_no_wait=True)
-        g.show_command('show', 'get')
-        g.custom_command('list', 'list_application_gateways')
-        g.command('start', 'begin_start')
-        g.command('stop', 'begin_stop')
-        g.custom_command('show-backend-health', 'show_ag_backend_health', min_api='2016-09-01', client_factory=cf_application_gateways)
-        g.generic_update_command('update', supports_no_wait=True, setter_name='begin_create_or_update', custom_func_name='update_application_gateway')
-        g.wait_command('wait')
+        g.custom_command('show-backend-health', 'show_ag_backend_health')
+
+        from .custom import ApplicationGatewayUpdate
+        self.command_table["network application-gateway update"] = ApplicationGatewayUpdate(loader=self)
 
     subresource_properties = [
         {'prop': 'authentication_certificates', 'name': 'auth-cert'},
@@ -611,79 +533,35 @@ def load_command_table(self, _):
 
     # region ExpressRoutes
     with self.command_group('network express-route', network_er_sdk) as g:
-        g.command('delete', 'begin_delete', supports_no_wait=True)
-        g.show_command('show', 'get')
-        g.command('get-stats', 'get_stats')
-        g.command('list-arp-tables', 'begin_list_arp_table')
-        g.command('list-route-tables', 'begin_list_routes_table', is_preview=True)
         g.command('list-route-tables-summary', 'begin_list_routes_table_summary', is_preview=True)
-        g.custom_command('create', 'create_express_route', supports_no_wait=True)
-        g.custom_command('list', 'list_express_route_circuits')
-        g.command('list-service-providers', 'list', command_type=network_ersp_sdk)
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_express_route', supports_no_wait=True)
-        g.wait_command('wait')
+        from azure.cli.command_modules.network.custom import ExpressRouteCreate, ExpressRouteUpdate
+        self.command_table['network express-route create'] = ExpressRouteCreate(loader=self)
+        self.command_table['network express-route update'] = ExpressRouteUpdate(loader=self)
 
-    with self.command_group('network express-route auth', network_erca_sdk) as g:
-        g.custom_command('create', 'create_express_route_auth', min_api='2019-09-01')
-        g.command('create', 'begin_create_or_update', max_api='2019-08-01', validator=process_auth_create_namespace)
-        g.command('delete', 'begin_delete')
-        g.show_command('show', 'get')
-        g.command('list', 'list')
+    with self.command_group('network express-route gateway connection'):
+        from azure.cli.command_modules.network.custom import ExpressRouteConnectionUpdate, ExpressRouteConnectionCreate
+        self.command_table['network express-route gateway connection create'] = ExpressRouteConnectionCreate(loader=self)
+        self.command_table['network express-route gateway connection update'] = ExpressRouteConnectionUpdate(loader=self)
 
-    with self.command_group('network express-route gateway', network_er_gateway_sdk) as g:
-        g.custom_command('create', 'create_express_route_gateway')
-        g.command('delete', 'begin_delete')
-        g.custom_command('list', 'list_express_route_gateways')
-        g.show_command('show', 'get')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_express_route_gateway', setter_arg_name='put_express_route_gateway_parameters')
-
-    with self.command_group('network express-route gateway connection', network_er_connection_sdk) as g:
-        g.custom_command('create', 'create_express_route_connection')
-        g.command('delete', 'begin_delete')
-        g.command('list', 'list')
-        g.show_command('show', 'get')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_express_route_connection', setter_arg_name='put_express_route_connection_parameters')
-
-    with self.command_group('network express-route peering', network_er_peering_sdk) as g:
-        g.custom_command('create', 'create_express_route_peering', client_factory=cf_express_route_circuit_peerings)
-        g.command('delete', 'begin_delete')
-        g.show_command('show', 'get')
-        g.command('list', 'list')
-        g.command('get-stats', 'get_peering_stats', command_type=network_er_sdk, is_preview=True)
-        g.generic_update_command('update', setter_name='begin_create_or_update', setter_arg_name='peering_parameters', custom_func_name='update_express_route_peering')
-
-    with self.command_group('network express-route peering connection', network_erconn_sdk) as g:
-        g.custom_command('create', 'create_express_route_peering_connection')
-        g.command('delete', 'begin_delete')
-        g.show_command('show')
-        g.command('list', 'list')
+    with self.command_group('network express-route peering'):
+        from azure.cli.command_modules.network.custom import ExpressRoutePeeringCreate, ExpressRoutePeeringUpdate
+        self.command_table['network express-route peering create'] = ExpressRoutePeeringCreate(loader=self)
+        self.command_table['network express-route peering update'] = ExpressRoutePeeringUpdate(loader=self)
 
     with self.command_group('network express-route peering connection ipv6-config', network_erconn_sdk) as g:
         g.custom_command('set', 'set_express_route_peering_connection_config')
         g.custom_command('remove', 'remove_express_route_peering_connection_config')
 
-    with self.command_group('network express-route peering peer-connection', network_perconn_sdk, is_preview=True) as g:
-        g.show_command('show', is_preview=True)
-        g.show_command('list', 'list', is_preview=True)
-
     with self.command_group('network express-route port', network_er_ports_sdk) as g:
-        g.custom_command('create', 'create_express_route_port')
-        g.command('delete', 'begin_delete')
-        g.custom_command('list', 'list_express_route_ports')
-        g.show_command('show')
-        g.generic_update_command('update', custom_func_name='update_express_route_port')
+        from azure.cli.command_modules.network.custom import ExpressRoutePortCreate
+        self.command_table['network express-route port create'] = ExpressRoutePortCreate(loader=self)
         g.custom_command('generate-loa', 'download_generated_loa_as_pdf')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_express_route_port')
 
     with self.command_group('network express-route port identity', min_api='2019-08-01') as g:
         g.custom_command('assign', 'assign_express_route_port_identity', supports_no_wait=True)
         g.custom_command('remove', 'remove_express_route_port_identity', supports_no_wait=True)
         g.custom_show_command('show', 'show_express_route_port_identity')
 
-    with self.command_group('network express-route port link', network_er_links_sdk) as g:
-        g.command('list', 'list')
-        g.show_command('show')
-
     with self.command_group('network express-route port link', network_er_ports_sdk) as g:
         g.generic_update_command('update',
                                  setter_name='begin_create_or_update',
@@ -692,10 +570,6 @@ def load_command_table(self, _):
                                  child_collection_prop_name='links',
                                  child_arg_name='link_name',
                                  min_api='2019-08-01')
-
-    with self.command_group('network express-route port location', network_er_port_locations_sdk) as g:
-        g.command('list', 'list')
-        g.show_command('show')
     # endregion
 
     # region PrivateEndpoint
@@ -833,9 +707,9 @@ def load_command_table(self, _):
                                  setter_name='begin_create_or_update',
                                  custom_func_name='set_lb_rule')
 
-    with self.command_group('network lb probe') as g:
-        g.custom_command('create', 'create_lb_probe')
-        g.custom_command('update', 'set_lb_probe')
+    with self.command_group("network lb probe") as g:
+        g.custom_command("create", "create_lb_probe")
+        g.custom_command("update", "update_lb_probe")
 
     with self.command_group('network lb probe', network_util) as g:
         g.command('delete', delete_lb_resource_property_entry('load_balancers', 'probes'))
@@ -907,8 +781,9 @@ def load_command_table(self, _):
     # endregion
 
     # region LocalGateways
-    with self.command_group('network local-gateway', network_lgw_sdk) as g:
-        g.command('list', 'list', table_transformer=transform_local_gateway_table_output)
+    with self.command_group('network local-gateway'):
+        from .aaz.latest.network.local_gateway import List
+        self.command_table['network local-gateway list'] = List(loader=self, table_transformer=transform_local_gateway_table_output)
     # endregion
 
     # region NetworkInterfaces: (NIC)
@@ -946,21 +821,16 @@ def load_command_table(self, _):
     # endregion
 
     # region NetworkSecurityGroups
-    with self.command_group('network nsg', network_nsg_sdk) as g:
+    with self.command_group('network nsg') as g:
         g.custom_command('create', 'create_nsg', transform=transform_nsg_create_output)
-        g.generic_update_command('update', setter_name='begin_create_or_update')
 
-    with self.command_group('network nsg rule', network_nsg_rule_sdk) as g:
+    with self.command_group('network nsg rule') as g:
         g.custom_command('list', 'list_nsg_rules', table_transformer=lambda x: [transform_nsg_rule_table_output(i) for i in x])
-        g.show_command('show', 'get', table_transformer=transform_nsg_rule_table_output)
-        g.custom_command('create', 'create_nsg_rule_2017_06_01', min_api='2017-06-01')
-        g.generic_update_command('update', setter_arg_name='security_rule_parameters', min_api='2017-06-01',
-                                 setter_name='begin_create_or_update',
-                                 custom_func_name='update_nsg_rule_2017_06_01', doc_string_source='SecurityRule')
-        g.custom_command('create', 'create_nsg_rule_2017_03_01', max_api='2017-03-01')
-        g.generic_update_command('update', max_api='2017-03-01', setter_arg_name='security_rule_parameters',
-                                 setter_name='begin_create_or_update',
-                                 custom_func_name='update_nsg_rule_2017_03_01', doc_string_source='SecurityRule')
+        g.custom_command('create', 'create_nsg_rule')
+        from .aaz.latest.network.nsg.rule import Show
+        self.command_table['network nsg rule show'] = Show(loader=self, table_transformer=transform_nsg_rule_table_output)
+        from azure.cli.command_modules.network.custom import NsgRuleUpdate
+        self.command_table['network nsg rule update'] = NsgRuleUpdate(loader=self)
     # endregion
 
     # region NetworkWatchers
@@ -1239,8 +1109,7 @@ def load_command_table(self, _):
     # endregion
 
     # region VirtualHub
-    with self.command_group('network routeserver', network_virtual_hub_sdk,
-                            custom_command_type=network_virtual_hub_update_sdk) as g:
+    with self.command_group('network routeserver') as g:
         g.custom_command('create', 'create_virtual_hub')
         g.custom_command('delete', 'delete_virtual_hub', supports_no_wait=True, confirmation=True)
     # endregion
