@@ -13,7 +13,9 @@ TYPE_CLIENT_MAPPING = {
 }
 
 
+# pylint: disable=too-many-statements
 def register_providers():
+    _register_one_provider("Microsoft.AgFoodPlatform/farmBeats", "2021-09-01-preview", True)
     _register_one_provider("Microsoft.Automation/automationAccounts", "2020-01-13-preview", True)
     _register_one_provider('Microsoft.Authorization/resourceManagementPrivateLinks', '2020-05-01', True)
     _register_one_provider('Microsoft.ApiManagement/service', '2021-08-01', True)
@@ -29,6 +31,8 @@ def register_providers():
     _register_one_provider('Microsoft.DBforMySQL/servers', '2018-06-01', False, '2017-12-01-preview')
     _register_one_provider('Microsoft.DBforMariaDB/servers', '2018-06-01', False)
     _register_one_provider('Microsoft.DBforPostgreSQL/servers', '2018-06-01', False, '2017-12-01-preview')
+    _register_one_provider("Microsoft.DesktopVirtualization/hostpools", '2021-04-01-preview', True)
+    _register_one_provider("Microsoft.DesktopVirtualization/workspaces", '2021-04-01-preview', True)
     _register_one_provider('Microsoft.Devices/IotHubs', '2020-03-01', True)
     _register_one_provider('Microsoft.DeviceUpdate/accounts', '2020-03-01-preview', True)
     _register_one_provider('Microsoft.DocumentDB/databaseAccounts', '2019-08-01-preview', False, '2020-03-01')
@@ -68,6 +72,7 @@ def register_providers():
     _register_one_provider('Microsoft.Kusto/clusters', '2021-08-27', True)
     _register_one_provider("Microsoft.KubernetesConfiguration/privateLinkScopes", '2022-04-02-preview', True)
     _register_one_provider("Microsoft.OpenEnergyPlatform/energyServices", '2022-04-04-preview', True)
+    _register_one_provider("Microsoft.MachineLearningServices/registries", '2022-10-01-preview', True)
 
 
 def _register_one_provider(provider, api_version, support_list_or_not, resource_get_api_version=None, support_connection_operation=True):  # pylint: disable=line-too-long
