@@ -17,10 +17,10 @@ from azure.mgmt.rdbms import mysql_flexibleservers
 from ._client_factory import get_mysql_flexible_management_client, cf_mysql_flexible_firewall_rules, \
     cf_mysql_flexible_db, cf_mysql_check_resource_availability, \
     cf_mysql_check_resource_availability_without_location, cf_mysql_flexible_private_dns_zone_suffix_operations, \
-    cf_mysql_flexible_servers, cf_mysql_flexible_replica
+    cf_mysql_flexible_servers, cf_mysql_flexible_replica, cf_mysql_flexible_adadmin, cf_mysql_flexible_config
 from ._flexible_server_util import resolve_poller, generate_missing_parameters, get_mysql_list_skus_info, \
     generate_password, parse_maintenance_window, replace_memory_optimized_tier, build_identity_and_data_encryption, \
-    get_identity_and_data_encryption
+    get_identity_and_data_encryption, get_tenant_id
 from .flexible_server_custom_common import create_firewall_rule
 from .flexible_server_virtual_network import prepare_private_network, prepare_private_dns_zone, prepare_public_network
 from .validators import mysql_arguments_validator, validate_mysql_replica, validate_server_name, validate_georestore_location, \
@@ -86,7 +86,7 @@ def flexible_server_create(cmd, client,
     list_skus_info = get_mysql_list_skus_info(db_context.cmd, location)
     iops_info = list_skus_info['iops_info']
 
-    server_result = firewall_name = subnet_id = None
+    server_result = firewall_name = None
 
     network, start_ip, end_ip = flexible_server_provision_network_resource(cmd=cmd,
                                                                            resource_group_name=resource_group_name,
@@ -122,7 +122,11 @@ def flexible_server_create(cmd, client,
 
     administrator_login_password = generate_password(administrator_login_password)
 
-    identity, data_encryption = build_identity_and_data_encryption(byok_identity, backup_byok_identity, byok_key, backup_byok_key)
+    identity, data_encryption = build_identity_and_data_encryption(db_engine='mysql',
+                                                                   byok_identity=byok_identity,
+                                                                   backup_byok_identity=backup_byok_identity,
+                                                                   byok_key=byok_key,
+                                                                   backup_byok_key=backup_byok_key)
 
     # Create mysql server
     # Note : passing public_access has no effect as the accepted values are 'Enabled' and 'Disabled'. So the value ends up being ignored.
@@ -156,6 +160,7 @@ def flexible_server_create(cmd, client,
     version = server_result.version
     sku = server_result.sku.name
     host = server_result.fully_qualified_domain_name
+    subnet_id = network.delegated_subnet_resource_id
 
     logger.warning('Make a note of your password. If you forget, you would have to reset your password with'
                    '\'az mysql flexible-server update -n %s -g %s -p <new-password>\'.',
@@ -281,7 +286,7 @@ def flexible_server_georestore(cmd, client,
 
         validate_server_name(db_context, server_name, provider + '/flexibleServers')
         validate_georestore_location(db_context, location)
-        validate_georestore_network(source_server_object, public_access, vnet, subnet)
+        validate_georestore_network(source_server_object, public_access, vnet, subnet, 'mysql')
 
         identity, data_encryption = get_identity_and_data_encryption(source_server_object)
 
@@ -364,7 +369,7 @@ def flexible_server_update_custom_func(cmd, client, instance,
                               backup_byok_key=backup_byok_key,
                               disable_data_encryption=disable_data_encryption)
 
-    list_skus_info = get_mysql_list_skus_info(db_context.cmd, location)
+    list_skus_info = get_mysql_list_skus_info(db_context.cmd, location, server_name=instance.name if instance else None)
     iops_info = list_skus_info['iops_info']
 
     server_module_path = instance.__module__
@@ -411,7 +416,11 @@ def flexible_server_update_custom_func(cmd, client, instance,
         else:
             instance.high_availability = mysql_flexibleservers.models.HighAvailability(mode=high_availability)
 
-    identity, data_encryption = build_identity_and_data_encryption(byok_identity, backup_byok_identity, byok_key, backup_byok_key)
+    identity, data_encryption = build_identity_and_data_encryption(db_engine='mysql',
+                                                                   byok_identity=byok_identity,
+                                                                   backup_byok_identity=backup_byok_identity,
+                                                                   byok_key=byok_key,
+                                                                   backup_byok_key=backup_byok_key)
     if disable_data_encryption:
         data_encryption = mysql_flexibleservers.models.DataEncryption(type="SystemManaged")
 
@@ -555,7 +564,7 @@ def flexible_parameter_update(client, server_name, configuration_name, resource_
 
 # Replica commands
 # Custom functions for server replica, will add MySQL part after backend ready in future
-def flexible_replica_create(cmd, client, resource_group_name, source_server, replica_name, zone=None, no_wait=False, location=None, sku_name=None, tier=None, **kwargs):
+def flexible_replica_create(cmd, client, resource_group_name, source_server, replica_name, zone=None, no_wait=False):
     provider = 'Microsoft.DBforMySQL'
     replica_name = replica_name.lower()
 
@@ -801,6 +810,222 @@ def get_free_iops(storage_in_mb, iops_info, tier, sku_name):
     return min(free_iops, max_supported_iops)
 
 
+# Custom functions for identity
+def flexible_server_identity_assign(cmd, client, resource_group_name, server_name, identities):
+    instance = client.get(resource_group_name, server_name)
+    if instance.replication_role == 'Replica':
+        raise CLIError("Cannot assign identities to a server with replication role. Use the primary server instead.")
+
+    identities_map = {}
+    for identity in identities:
+        identities_map[identity] = {}
+
+    parameters = {
+        'identity': mysql_flexibleservers.models.Identity(
+            user_assigned_identities=identities_map,
+            type="UserAssigned")}
+
+    replica_operations_client = cf_mysql_flexible_replica(cmd.cli_ctx, '_')
+
+    replicas = replica_operations_client.list_by_server(resource_group_name, server_name)
+    for replica in replicas:
+        resolve_poller(
+            client.begin_update(
+                resource_group_name=resource_group_name,
+                server_name=replica.name,
+                parameters=parameters),
+            cmd.cli_ctx, 'Adding identities to replica {}'.format(replica.name)
+        )
+
+    result = resolve_poller(
+        client.begin_update(
+            resource_group_name=resource_group_name,
+            server_name=server_name,
+            parameters=parameters),
+        cmd.cli_ctx, 'Adding identities to server {}'.format(server_name)
+    )
+
+    return result.identity
+
+
+def flexible_server_identity_remove(cmd, client, resource_group_name, server_name, identities):
+    instance = client.get(resource_group_name, server_name)
+
+    if instance.replication_role == 'Replica':
+        raise CLIError("Cannot remove identities from a server with replication role. Use the primary server instead.")
+
+    if instance.data_encryption:
+        primary_id = instance.data_encryption.primary_user_assigned_identity_id
+        backup_id = instance.data_encryption.geo_backup_user_assigned_identity_id
+
+        if primary_id and primary_id.lower() in [identity.lower() for identity in identities]:
+            raise CLIError("Cannot remove identity {} because it's used for data encryption.".format(primary_id))
+
+        if backup_id and backup_id.lower() in [identity.lower() for identity in identities]:
+            raise CLIError("Cannot remove identity {} because it's used for data encryption.".format(backup_id))
+
+    admin_operations_client = cf_mysql_flexible_adadmin(cmd.cli_ctx, '_')
+
+    admins = admin_operations_client.list_by_server(resource_group_name, server_name)
+    common_identities = [identity for identity in identities if identity.lower() in [admin.identity_resource_id.lower() for admin in admins]]
+    if len(common_identities) > 0:
+        raise CLIError("Cannot remove identities {} because they're used for server admin.".format(common_identities))
+
+    identities_map = {}
+    for identity in identities:
+        identities_map[identity] = None
+
+    if not (instance.identity and instance.identity.user_assigned_identities) or \
+       all(key.lower() in [identity.lower() for identity in identities] for key in instance.identity.user_assigned_identities.keys()):
+        parameters = {
+            'identity': mysql_flexibleservers.models.Identity(
+                type="None")}
+    else:
+        parameters = {
+            'identity': mysql_flexibleservers.models.Identity(
+                user_assigned_identities=identities_map,
+                type="UserAssigned")}
+
+    replica_operations_client = cf_mysql_flexible_replica(cmd.cli_ctx, '_')
+
+    replicas = replica_operations_client.list_by_server(resource_group_name, server_name)
+    for replica in replicas:
+        resolve_poller(
+            client.begin_update(
+                resource_group_name=resource_group_name,
+                server_name=replica.name,
+                parameters=parameters),
+            cmd.cli_ctx, 'Removing identities from replica {}'.format(replica.name)
+        )
+
+    result = resolve_poller(
+        client.begin_update(
+            resource_group_name=resource_group_name,
+            server_name=server_name,
+            parameters=parameters),
+        cmd.cli_ctx, 'Removing identities from server {}'.format(server_name)
+    )
+
+    return result.identity or mysql_flexibleservers.models.Identity()
+
+
+def flexible_server_identity_list(client, resource_group_name, server_name):
+    server = client.get(resource_group_name, server_name)
+    return server.identity or mysql_flexibleservers.models.Identity()
+
+
+def flexible_server_identity_show(client, resource_group_name, server_name, identity):
+    server = client.get(resource_group_name, server_name)
+
+    for key, value in server.identity.user_assigned_identities.items():
+        if key.lower() == identity.lower():
+            return value
+
+    raise CLIError("Identity '{}' does not exist in server {}.".format(identity, server_name))
+
+
+# Custom functions for ad-admin
+def flexible_server_ad_admin_set(cmd, client, resource_group_name, server_name, login, sid, identity):
+    server_operations_client = cf_mysql_flexible_servers(cmd.cli_ctx, '_')
+    replica_operations_client = cf_mysql_flexible_replica(cmd.cli_ctx, '_')
+
+    instance = server_operations_client.get(resource_group_name, server_name)
+
+    if instance.replication_role == 'Replica':
+        raise CLIError("Cannot create an AD admin on a server with replication role. Use the primary server instead.")
+
+    parameters = {
+        'identity': mysql_flexibleservers.models.Identity(
+            user_assigned_identities={identity: {}},
+            type="UserAssigned")}
+
+    replicas = replica_operations_client.list_by_server(resource_group_name, server_name)
+    for replica in replicas:
+        if not (replica.identity and replica.identity.user_assigned_identities and
+           identity.lower() in [key.lower() for key in replica.identity.user_assigned_identities.keys()]):
+            resolve_poller(
+                server_operations_client.begin_update(
+                    resource_group_name=resource_group_name,
+                    server_name=replica.name,
+                    parameters=parameters),
+                cmd.cli_ctx, 'Adding identity {} to replica {}'.format(identity, replica.name)
+            )
+
+    if not (instance.identity and instance.identity.user_assigned_identities and
+       identity.lower() in [key.lower() for key in instance.identity.user_assigned_identities.keys()]):
+        resolve_poller(
+            server_operations_client.begin_update(
+                resource_group_name=resource_group_name,
+                server_name=server_name,
+                parameters=parameters),
+            cmd.cli_ctx, 'Adding identity {} to server {}'.format(identity, server_name))
+
+    parameters = {
+        'administratorType': 'ActiveDirectory',
+        'login': login,
+        'sid': sid,
+        'tenant_id': get_tenant_id(),
+        'identity_resource_id': identity
+    }
+
+    return client.begin_create_or_update(
+        resource_group_name=resource_group_name,
+        server_name=server_name,
+        administrator_name='ActiveDirectory',
+        parameters=parameters)
+
+
+def flexible_server_ad_admin_delete(cmd, client, resource_group_name, server_name):
+    server_operations_client = cf_mysql_flexible_servers(cmd.cli_ctx, '_')
+
+    instance = server_operations_client.get(resource_group_name, server_name)
+
+    if instance.replication_role == 'Replica':
+        raise CLIError("Cannot delete an AD admin on a server with replication role. Use the primary server instead.")
+
+    replica_operations_client = cf_mysql_flexible_replica(cmd.cli_ctx, '_')
+    config_operations_client = cf_mysql_flexible_config(cmd.cli_ctx, '_')
+
+    resolve_poller(
+        client.begin_delete(
+            resource_group_name=resource_group_name,
+            server_name=server_name,
+            administrator_name='ActiveDirectory'),
+        cmd.cli_ctx, 'Dropping AD admin in server {}'.format(server_name))
+
+    configuration_name = 'aad_auth_only'
+    parameters = mysql_flexibleservers.models.Configuration(
+        name=configuration_name,
+        value='OFF',
+        source='user-override'
+    )
+
+    replicas = replica_operations_client.list_by_server(resource_group_name, server_name)
+    for replica in replicas:
+        if config_operations_client.get(resource_group_name, replica.name, configuration_name).value == "ON":
+            resolve_poller(
+                config_operations_client.begin_update(resource_group_name, replica.name, configuration_name, parameters),
+                cmd.cli_ctx, 'Disabling aad_auth_only in replica {}'.format(replica.name))
+
+    if config_operations_client.get(resource_group_name, server_name, configuration_name).value == "ON":
+        resolve_poller(
+            config_operations_client.begin_update(resource_group_name, server_name, configuration_name, parameters),
+            cmd.cli_ctx, 'Disabling aad_auth_only in server {}'.format(server_name))
+
+
+def flexible_server_ad_admin_list(client, resource_group_name, server_name):
+    return client.list_by_server(
+        resource_group_name=resource_group_name,
+        server_name=server_name)
+
+
+def flexible_server_ad_admin_show(client, resource_group_name, server_name):
+    return client.get(
+        resource_group_name=resource_group_name,
+        server_name=server_name,
+        administrator_name='ActiveDirectory')
+
+
 # pylint: disable=too-many-instance-attributes, too-few-public-methods, useless-object-inheritance
 class DbContext(object):
     def __init__(self, cmd=None, azure_sdk=None, logging_name=None, cf_firewall=None, cf_db=None,
