@@ -18,6 +18,8 @@ _change_type_to_color = {
     ChangeType.deploy: Color.BLUE,
     ChangeType.no_change: Color.RESET,
     ChangeType.ignore: Color.GRAY,
+    ChangeType.unsupported: Color.GRAY,
+    PropertyChangeType.no_effect: Color.GRAY,
 }
 
 _property_change_type_to_color = {
@@ -25,6 +27,7 @@ _property_change_type_to_color = {
     PropertyChangeType.delete: Color.ORANGE,
     PropertyChangeType.modify: Color.PURPLE,
     PropertyChangeType.array: Color.PURPLE,
+    PropertyChangeType.no_effect: Color.GRAY,
 }
 
 _change_type_to_symbol = {
@@ -34,6 +37,8 @@ _change_type_to_symbol = {
     ChangeType.deploy: Symbol.EXCLAMATION_POINT,
     ChangeType.no_change: Symbol.EQUAL,
     ChangeType.ignore: Symbol.ASTERISK,
+    ChangeType.unsupported: Symbol.CROSS,
+    PropertyChangeType.no_effect: Symbol.CROSS,
 }
 
 _property_change_type_to_symbol = {
@@ -41,6 +46,7 @@ _property_change_type_to_symbol = {
     PropertyChangeType.delete: Symbol.MINUS,
     PropertyChangeType.modify: Symbol.TILDE,
     PropertyChangeType.array: Symbol.TILDE,
+    PropertyChangeType.no_effect: Symbol.CROSS,
 }
 
 _change_type_to_weight = {
@@ -49,7 +55,9 @@ _change_type_to_weight = {
     ChangeType.deploy: 2,
     ChangeType.modify: 3,
     ChangeType.no_change: 4,
-    ChangeType.ignore: 5,
+    ChangeType.unsupported: 5,
+    ChangeType.ignore: 6,
+    PropertyChangeType.no_effect: 7,
 }
 
 _property_change_type_to_weight = {
@@ -57,6 +65,7 @@ _property_change_type_to_weight = {
     PropertyChangeType.create: 1,
     PropertyChangeType.modify: 2,
     PropertyChangeType.array: 2,
+    PropertyChangeType.no_effect: 3,
 }
 
 
@@ -72,7 +81,7 @@ def format_what_if_operation_result(what_if_operation_result, enable_color=True)
 def _format_noise_notice(builder):
     builder.append_line(
         """Note: The result may contain false positive predictions (noise).
-You can help us improve the accuracy of the result by opening an issue here: https://aka.ms/WhatIfIssues."""
+You can help us improve the accuracy of the result by opening an issue here: https://aka.ms/WhatIfIssues"""
     )
     builder.append_line()
 
@@ -108,7 +117,7 @@ def _format_change_type_legend(builder, resource_changes):
         change_type_color = _change_type_to_color[change_type]
         _format_indent(builder)
         builder.append(change_type_symbol, change_type_color).append(Symbol.WHITE_SPACE)
-        builder.append_line(change_type.value.title())
+        builder.append_line(change_type.title())
 
 
 def _format_resource_changes_stats(builder, resource_changes):
@@ -127,7 +136,7 @@ def _format_resource_changes_stats(builder, resource_changes):
     builder.append(", ".join(change_type_stats)).append(".")
 
 
-def _format_change_type_count(change_type, count):
+def _format_change_type_count(change_type, count):  # pylint: disable=too-many-return-statements
     if change_type == ChangeType.create:
         return f"{count} to create"
     if change_type == ChangeType.delete:
@@ -140,6 +149,8 @@ def _format_change_type_count(change_type, count):
         return f"{count} to ignore"
     if change_type == ChangeType.no_change:
         return f"{count} no change"
+    if change_type == ChangeType.unsupported:
+        return f"{count} unsupported"
 
     raise ValueError(f"Invalid ChangeType: {change_type}")
 
@@ -190,7 +201,7 @@ def _format_resource_change(builder, resource_change, is_last):
     elif change_type == ChangeType.delete and resource_change.before:
         _format_json(builder, resource_change.before, indent_level=2)
 
-    elif change_type == ChangeType.modify and resource_change.delta:
+    elif resource_change.delta:
         with builder.new_color_scope(Color.RESET):
             builder.append_line()
             _format_property_changes(
@@ -256,6 +267,9 @@ def _format_property_change(builder, property_change, max_path_length, indent_le
     elif property_change_type == PropertyChangeType.array:
         _format_property_change_path(builder, property_change, "children", max_path_length, indent_level)
         _format_property_array_change(builder, children, indent_level + 1)
+    elif property_change_type == PropertyChangeType.no_effect:
+        _format_property_change_path(builder, property_change, "after", max_path_length, indent_level)
+        _format_property_no_effect(builder, after, indent_level + 1)
     else:
         raise ValueError(f"Unknown property change type: {property_change_type}.")
 
@@ -290,6 +304,11 @@ def _format_property_change_type(builder, property_change_type):
     builder.append(property_change_symbol, property_change_color).append(Symbol.WHITE_SPACE)
 
 
+def _format_property_no_effect(builder, value, indent_level):
+    with builder.new_color_scope(_property_change_type_to_color[PropertyChangeType.no_effect]):
+        _format_json(builder, value, indent_level=indent_level)
+
+
 def _format_property_create(builder, value, indent_level):
     with builder.new_color_scope(_property_change_type_to_color[PropertyChangeType.create]):
         _format_json(builder, value, indent_level=indent_level)
@@ -315,7 +334,7 @@ def _format_property_modify(builder, before, after, children, indent_level):
         # Space before =>
         if _is_non_empty_object(before):
             builder.append_line()
-            _format_indent(indent_level)
+            _format_indent(builder, indent_level)
         else:
             builder.append(Symbol.WHITE_SPACE)
 
