@@ -325,6 +325,15 @@ def get_security_discovered_security_solution(client, resource_name, resource_gr
     return client.discovered_security_solutions.get(resource_group_name, resource_name)
 
 
+# --------------------------------------------------------------------------------------------
+# Security Solutions
+# --------------------------------------------------------------------------------------------
+
+def list_security_security_solutions(client):
+
+    return client.security_solutions.list()
+
+
 # --------------------------------------------------------------------------------------------
 # External Security Solutions
 # --------------------------------------------------------------------------------------------
@@ -388,6 +397,15 @@ def get_security_location(client, resource_name):
     return client.get()
 
 
+# --------------------------------------------------------------------------------------------
+# securitySolutionsReferenceData
+# --------------------------------------------------------------------------------------------
+
+def list_security_solutions_reference_data(client):
+
+    return client.list()
+
+
 # --------------------------------------------------------------------------------------------
 # Security Pricings
 # --------------------------------------------------------------------------------------------
