@@ -4,9 +4,9 @@
 # --------------------------------------------------------------------------------------------
 
 import unittest
-import mock
+from unittest import mock
 from argparse import Namespace
-from six import StringIO
+from io import StringIO
 
 from knack import CLI
 
