@@ -10,13 +10,15 @@ from azure.synapse.artifacts.models import (LinkedService, Dataset, PipelineReso
                                             Trigger, DataFlow, BigDataPoolReference, NotebookSessionProperties,
                                             NotebookResource, SparkJobDefinition, SqlScriptResource, SqlScriptFolder,
                                             SqlScriptContent, SqlScriptMetadata, SqlScript, SqlConnection,
-                                            NotebookFolder)
+                                            NotebookFolder, LinkConnectionResource, LinkTableRequest,
+                                            QueryTableStatusRequest, SecureString)
 from azure.cli.core.util import sdk_no_wait, CLIError
 from azure.core.exceptions import ResourceNotFoundError
 from .._client_factory import (cf_synapse_linked_service, cf_synapse_dataset, cf_synapse_pipeline,
                                cf_synapse_pipeline_run, cf_synapse_trigger, cf_synapse_trigger_run,
                                cf_synapse_data_flow, cf_synapse_notebook, cf_synapse_spark_pool,
-                               cf_synapse_spark_job_definition, cf_synapse_library, cf_synapse_sql_script)
+                               cf_synapse_spark_job_definition, cf_synapse_library, cf_synapse_sql_script,
+                               cf_synapse_link_connection)
 from ..constant import EXECUTOR_SIZE, SPARK_SERVICE_ENDPOINT_API_VERSION
 
 
@@ -552,3 +554,76 @@ def export_sql_script(cmd, workspace_name, output_folder, sql_script_name=None):
                 from azure.cli.core.azclierror import InvalidArgumentValueError
                 err_msg = 'Unable to export to file: {}'.format(path)
                 raise InvalidArgumentValueError(err_msg)
+
+
+def list_link_connection(cmd, workspace_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.list_link_connections_by_workspace()
+
+
+def get_link_connection(cmd, workspace_name, link_connection_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.get_link_connection(link_connection_name)
+
+
+def create_or_update_link_connection(cmd, workspace_name, link_connection_name, definition_file):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    info = definition_file['properties']
+    properties_file = {}
+    properties_file['sourceDatabase'] = info['sourceDatabase']
+    properties_file['targetDatabase'] = info['targetDatabase']
+    properties_file['compute'] = info['compute']
+    if 'landingZone' in properties_file:
+        properties_file['landingZone'] = info['landingZone']
+    properties = LinkConnectionResource(properties=properties_file)
+    return client.create_or_update_link_connection(link_connection_name, properties)
+
+
+def delete_link_connection(cmd, workspace_name, link_connection_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.delete_link_connection(link_connection_name)
+
+
+def get_link_connection_status(cmd, workspace_name, link_connection_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.get_detailed_status(link_connection_name)
+
+
+def start_link_connection(cmd, workspace_name, link_connection_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.start(link_connection_name)
+
+
+def stop_link_connection(cmd, workspace_name, link_connection_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.stop(link_connection_name)
+
+
+def synapse_list_link_table(cmd, workspace_name, link_connection_name):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    return client.list_link_tables(link_connection_name).value
+
+
+def synapse_edit_link_table(cmd, workspace_name, link_connection_name, definition_file):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    linkTableRequset_list = []
+    for i in range(0, len(definition_file['linkTables'])):
+        linkTableRequset = LinkTableRequest.from_dict(definition_file['linkTables'][i])
+        linkTableRequset_list.append(linkTableRequset)
+    return client.edit_tables(link_connection_name, linkTableRequset_list)
+
+
+def synapse_get_link_tables_status(cmd, workspace_name, link_connection_name, max_segment_count=50,
+                                   continuation_token=None):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    query_table_status_request = QueryTableStatusRequest(
+        max_segment_count=max_segment_count,
+        continuation_token=continuation_token
+    )
+    return client.query_table_status(link_connection_name, query_table_status_request)
+
+
+def synapse_update_landing_zone_credential(cmd, workspace_name, link_connection_name, sas_token):
+    client = cf_synapse_link_connection(cmd.cli_ctx, workspace_name)
+    sas_tokens = SecureString(value=sas_token)
+    return client.update_landing_zone_credential(link_connection_name, sas_tokens)
