@@ -303,7 +303,7 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
         enable_hotpatching=None, platform_fault_domain=None, security_type=None, enable_secure_boot=None,
         enable_vtpm=None, count=None, edge_zone=None, os_disk_delete_option=None, user_data=None,
         capacity_reservation_group=None, enable_hibernation=None, v_cpus_available=None, v_cpus_per_core=None,
-        os_disk_security_encryption_type=None, os_disk_secure_vm_disk_encryption_set=None):
+        os_disk_security_encryption_type=None, os_disk_secure_vm_disk_encryption_set=None, disk_controller_type=None):
 
     os_caching = disk_info['os'].get('caching')
 
@@ -556,6 +556,9 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
         if disk_info['os'].get('diffDiskSettings'):
             profile['osDisk']['diffDiskSettings'] = disk_info['os']['diffDiskSettings']
 
+        if disk_controller_type is not None:
+            profile['diskControllerType'] = disk_controller_type
+
         return profile
 
     vm_properties = {'hardwareProfile': {'vmSize': size}, 'networkProfile': {'networkInterfaces': nics},
@@ -864,6 +867,38 @@ def build_load_balancer_resource(cmd, name, location, tags, backend_pool_name, n
     return lb
 
 
+def build_nat_rule_v2(cmd, name, location, lb_name, frontend_ip_name, backend_pool_name, backend_port, instance_count,
+                      disable_overprovision):
+    lb_id = "resourceId('Microsoft.Network/loadBalancers', '{}')".format(lb_name)
+
+    nat_rule = {
+        "type": "Microsoft.Network/loadBalancers/inboundNatRules",
+        "apiVersion": get_target_network_api(cmd.cli_ctx),
+        "name": name,
+        "location": location,
+        "properties": {
+            "frontendIPConfiguration": {
+                'id': "[concat({}, '/frontendIPConfigurations/', '{}')]".format(lb_id, frontend_ip_name)
+            },
+            "backendAddressPool": {
+                "id": "[concat({}, '/backendAddressPools/', '{}')]".format(lb_id, backend_pool_name)
+            },
+            "backendPort": backend_port,
+            "frontendPortRangeStart": "50000",
+            # This logic comes from the template of `inboundNatPools` to keep consistent with NAT pool
+            # keep 50119 as minimum for backward compat, and ensure over-provision is taken care of
+            "frontendPortRangeEnd": str(max(50119, 49999 + instance_count * (1 if disable_overprovision else 2))),
+            "protocol": "tcp",
+            "idleTimeoutInMinutes": 5
+        },
+        "dependsOn": [
+            "[concat('Microsoft.Network/loadBalancers/', '{}')]".format(lb_name)
+        ]
+    }
+
+    return nat_rule
+
+
 def build_vmss_storage_account_pool_resource(_, loop_name, location, tags, storage_sku, edge_zone=None):
 
     storage_resource = {
@@ -911,7 +946,8 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
                         enable_auto_update=None, patch_mode=None, enable_agent=None, security_type=None,
                         enable_secure_boot=None, enable_vtpm=None, automatic_repairs_action=None, v_cpus_available=None,
                         v_cpus_per_core=None, os_disk_security_encryption_type=None,
-                        os_disk_secure_vm_disk_encryption_set=None, os_disk_delete_option=None):
+                        os_disk_secure_vm_disk_encryption_set=None, os_disk_delete_option=None,
+                        regular_priority_count=None, regular_priority_percentage=None, disk_controller_type=None):
 
     # Build IP configuration
     ip_configuration = {}
@@ -1102,6 +1138,8 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
             data_disk['diskMBpsReadWrite'] = data_disk_mbps[i]
     if data_disks:
         storage_properties['dataDisks'] = data_disks
+    if disk_controller_type is not None:
+        storage_properties['diskControllerType'] = disk_controller_type
 
     # Build OS Profile
     os_profile = {}
@@ -1257,6 +1295,14 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
         if spot_restore_timeout:
             vmss_properties['spotRestorePolicy']['restoreTimeout'] = spot_restore_timeout
 
+    if regular_priority_count is not None or regular_priority_percentage is not None:
+        priority_mix_policy = {}
+        if regular_priority_count is not None:
+            priority_mix_policy['baseRegularPriorityCount'] = regular_priority_count
+        if regular_priority_percentage is not None:
+            priority_mix_policy['regularPriorityPercentageAboveBase'] = regular_priority_percentage
+        vmss_properties['priorityMixPolicy'] = priority_mix_policy
+
     if license_type:
         virtual_machine_profile['licenseType'] = license_type
 
